@@ -19,8 +19,11 @@ options:
   deviceIPAddress:
     description: DeviceIPAddress query parameter. Device Management IP Address.
     type: str
+  headers:
+    description: Additional headers.
+    type: dict
 requirements:
-- dnacentersdk >= 2.5.5
+- dnacentersdk >= 2.7.2
 - python >= 3.5
 seealso:
 - name: Cisco DNA Center documentation for Fabric Wireless RemoveWLCFromFabricDomain
@@ -47,9 +50,9 @@ EXAMPLES = r"""
     dnac_version: "{{dnac_version}}"
     dnac_debug: "{{dnac_debug}}"
     deviceIPAddress: string
+    headers: '{{my_headers | from_json}}'
 
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
