@@ -440,8 +440,7 @@ def async_wait_create(config, result, client, timeout):
     path_parameters = {
         "subnet_id": ["subnet", "id"],
     }
-    data = dict((key, navigate_value(result, path))
-                for key, path in path_parameters.items())
+    data = {key: navigate_value(result, path) for key, path in path_parameters.items()}
 
     url = build_path(module, "subnets/{subnet_id}", data)
 
@@ -538,8 +537,7 @@ def async_wait_update(config, result, client, timeout):
     path_parameters = {
         "subnet_id": ["subnet", "id"],
     }
-    data = dict((key, navigate_value(result, path))
-                for key, path in path_parameters.items())
+    data = {key: navigate_value(result, path) for key, path in path_parameters.items()}
 
     url = build_path(module, "subnets/{subnet_id}", data)
 
