@@ -6,6 +6,7 @@
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
+
 __metaclass__ = type
 
 
@@ -35,8 +36,19 @@ options:
       nothing will be changed.
     - If you need to add all tables to the publication with the same name,
       drop existent and create new without passing I(tables).
+    - Mutually exclusive with I(tables_in_schema).
     type: list
     elements: str
+  tables_in_schema:
+    description:
+    - Specifies a list of schemas to add to the publication to replicate changes
+      for all tables in those schemas.
+    - If you want to remove all schemas, explicitly pass an empty list C([]).
+    - Supported since PostgreSQL 15.
+    - Mutually exclusive with I(tables).
+    type: list
+    elements: str
+    version_added: '3.5.0'
   state:
     description:
     - The publication state.
@@ -74,6 +86,12 @@ options:
     type: bool
     default: true
     version_added: '0.2.0'
+  comment:
+    description:
+    - Sets a comment on the publication.
+    - To reset the comment, pass an empty string.
+    type: str
+    version_added: '3.3.0'
 
 notes:
 - PostgreSQL version must be 10 or greater.
@@ -104,6 +122,7 @@ EXAMPLES = r'''
   community.postgresql.postgresql_publication:
     db: test
     name: acme
+    comment: Made by Ansible
 
 - name: Create publication "acme" publishing only prices and vehicles tables
   community.postgresql.postgresql_publication:
@@ -112,6 +131,18 @@ EXAMPLES = r'''
     - prices
     - vehicles
 
+- name: Create a new publication "acme" for tables in schema "myschema"
+  community.postgresql.postgresql_publication:
+    db: test
+    name: acme
+    tables_in_schema: myschema
+
+- name: Remove all schemas from "acme" publication
+  community.postgresql.postgresql_publication:
+    db: test
+    name: acme
+    tables_in_schema: []
+
 - name: >
     Create publication "acme", set user alice as an owner, targeting all tables
     Allowable DML operations are INSERT and UPDATE only
@@ -176,26 +207,22 @@ parameters:
 '''
 
 
-try:
-    from psycopg2.extras import DictCursor
-except ImportError:
-    # psycopg2 is checked by connect_to_db()
-    # from ansible.module_utils.postgres
-    pass
-
 from ansible.module_utils.basic import AnsibleModule
+from ansible.module_utils.six import iteritems
 from ansible_collections.community.postgresql.plugins.module_utils.database import (
     check_input,
     pg_quote_identifier,
 )
 from ansible_collections.community.postgresql.plugins.module_utils.postgres import (
     connect_to_db,
-    exec_sql,
     ensure_required_libs,
+    exec_sql,
     get_conn_params,
+    get_server_version,
+    pg_cursor_args,
     postgres_common_argument_spec,
+    set_comment,
 )
-from ansible.module_utils.six import iteritems
 
 SUPPORTED_PG_VERSION = 10000
 
@@ -228,28 +255,30 @@ class PgPublication():
 
     Args:
         module (AnsibleModule): Object of AnsibleModule class.
-        cursor (cursor): Cursor object of psycopg2 library to work with PostgreSQL.
+        cursor (cursor): Cursor object of psycopg library to work with PostgreSQL.
         name (str): The name of the publication.
 
     Attributes:
         module (AnsibleModule): Object of AnsibleModule class.
-        cursor (cursor): Cursor object of psycopg2 library to work with PostgreSQL.
+        cursor (cursor): Cursor object of psycopg library to work with PostgreSQL.
         name (str): Name of the publication.
         executed_queries (list): List of executed queries.
         attrs (dict): Dict with publication attributes.
         exists (bool): Flag indicates the publication exists or not.
     """
 
-    def __init__(self, module, cursor, name):
+    def __init__(self, module, cursor, name, pg_srv_ver):
         self.module = module
         self.cursor = cursor
         self.name = name
+        self.pg_srv_ver = pg_srv_ver
         self.executed_queries = []
         self.attrs = {
             'alltables': False,
             'tables': [],
             'parameters': {},
             'owner': '',
+            'schemas': [],
         }
         self.exists = self.check_pub()
 
@@ -276,6 +305,7 @@ class PgPublication():
             return False
 
         self.attrs['owner'] = pub_info.get('pubowner')
+        self.attrs['comment'] = pub_info.get('comment') if pub_info.get('comment') is not None else ''
 
         # Publication DML operations:
         self.attrs['parameters']['publish'] = {}
@@ -288,25 +318,29 @@ class PgPublication():
         # If alltables flag is False, get the list of targeted tables:
         if not pub_info.get('puballtables'):
             table_info = self.__get_tables_pub_info()
-            # Join sublists [['schema', 'table'], ...] to ['schema.table', ...]
-            # for better representation:
             for i, schema_and_table in enumerate(table_info):
-                table_info[i] = pg_quote_identifier('.'.join(schema_and_table), 'table')
+                table_info[i] = pg_quote_identifier(schema_and_table["schema_dot_table"], 'table')
 
             self.attrs['tables'] = table_info
+
+            # FOR TABLES IN SCHEMA statement is supported since PostgreSQL 15
+            if self.pg_srv_ver >= 150000:
+                self.attrs['schemas'] = self.__get_schema_pub_info()
         else:
             self.attrs['alltables'] = True
 
         # Publication exists:
         return True
 
-    def create(self, tables, params, owner, check_mode=True):
+    def create(self, tables, tables_in_schema, params, owner, comment, check_mode=True):
         """Create the publication.
 
         Args:
             tables (list): List with names of the tables that need to be added to the publication.
+            tables_in_schema (list): List of schema names of the tables that need to be added to the publication.
             params (dict): Dict contains optional publication parameters and their values.
             owner (str): Name of the publication owner.
+            comment (str): Comment on the publication.
 
         Kwargs:
             check_mode (bool): If True, don't actually change anything,
@@ -321,6 +355,9 @@ class PgPublication():
 
         if tables:
             query_fragments.append("FOR TABLE %s" % ', '.join(tables))
+        elif tables_in_schema:
+            tables_in_schema = [pg_quote_identifier(schema, 'schema') for schema in tables_in_schema]
+            query_fragments.append("FOR TABLES IN SCHEMA %s" % ', '.join(tables_in_schema))
         else:
             query_fragments.append("FOR ALL TABLES")
 
@@ -340,15 +377,21 @@ class PgPublication():
             # executed_queries and return:
             self.__pub_set_owner(owner, check_mode=check_mode)
 
+        if comment is not None:
+            set_comment(self.cursor, comment, 'publication',
+                        self.name, check_mode, self.executed_queries)
+
         return changed
 
-    def update(self, tables, params, owner, check_mode=True):
+    def update(self, tables, tables_in_schema, params, owner, comment, check_mode=True):
         """Update the publication.
 
         Args:
             tables (list): List with names of the tables that need to be presented in the publication.
+            tables_in_schema (list): List of schema names of the tables that need to be presented in the publication.
             params (dict): Dict contains optional publication parameters and their values.
             owner (str): Name of the publication owner.
+            comment (str): Comment on the publication.
 
         Kwargs:
             check_mode (bool): If True, don't actually change anything,
@@ -365,11 +408,10 @@ class PgPublication():
             # 1. If needs to add table to the publication:
             for tbl in tables:
                 if tbl not in self.attrs['tables']:
-                    # If needs to add table to the publication:
                     changed = self.__pub_add_table(tbl, check_mode=check_mode)
 
             # 2. if there is a table in targeted tables
-            # that's not presented in the passed tables:
+            # that's not present in the passed tables:
             for tbl in self.attrs['tables']:
                 if tbl not in tables:
                     changed = self.__pub_drop_table(tbl, check_mode=check_mode)
@@ -377,6 +419,19 @@ class PgPublication():
         elif tables and self.attrs['alltables']:
             changed = self.__pub_set_tables(tables, check_mode=check_mode)
 
+        elif tables_in_schema is not None:
+
+            # 1. If needs to add schema to the publication:
+            for schema in tables_in_schema:
+                if schema not in self.attrs['schemas']:
+                    changed = self.__pub_add_schema(schema, check_mode=check_mode)
+
+            # 2. if there is a schema that's already in the publication
+            # but not present in the passed schemas we remove it from the publication:
+            for schema in self.attrs['schemas']:
+                if schema not in tables_in_schema:
+                    changed = self.__pub_drop_schema(schema, check_mode=check_mode)
+
         # Update pub parameters:
         if params:
             for key, val in iteritems(params):
@@ -414,6 +469,10 @@ class PgPublication():
             if owner != self.attrs['owner']:
                 changed = self.__pub_set_owner(owner, check_mode=check_mode)
 
+        if comment is not None and comment != self.attrs['comment']:
+            changed = set_comment(self.cursor, comment, 'publication',
+                                  self.name, check_mode, self.executed_queries)
+
         return changed
 
     def drop(self, cascade=False, check_mode=True):
@@ -448,13 +507,15 @@ class PgPublication():
                                       "AND column_name = 'pubtruncate'"), add_to_executed=False)
 
         if pgtrunc_sup:
-            query = ("SELECT r.rolname AS pubowner, p.puballtables, p.pubinsert, "
+            query = ("SELECT obj_description(p.oid, 'pg_publication') AS comment, "
+                     "r.rolname AS pubowner, p.puballtables, p.pubinsert, "
                      "p.pubupdate , p.pubdelete, p.pubtruncate FROM pg_publication AS p "
                      "JOIN pg_catalog.pg_roles AS r "
                      "ON p.pubowner = r.oid "
                      "WHERE p.pubname = %(pname)s")
         else:
-            query = ("SELECT r.rolname AS pubowner, p.puballtables, p.pubinsert, "
+            query = ("SELECT obj_description(p.oid, 'pg_publication') AS comment, "
+                     "r.rolname AS pubowner, p.puballtables, p.pubinsert, "
                      "p.pubupdate , p.pubdelete FROM pg_publication AS p "
                      "JOIN pg_catalog.pg_roles AS r "
                      "ON p.pubowner = r.oid "
@@ -472,10 +533,28 @@ class PgPublication():
         Returns:
             List of dicts with published tables.
         """
-        query = ("SELECT schemaname, tablename "
+        query = ("SELECT schemaname || '.' || tablename as schema_dot_table "
                  "FROM pg_publication_tables WHERE pubname = %(pname)s")
         return exec_sql(self, query, query_params={'pname': self.name}, add_to_executed=False)
 
+    def __get_schema_pub_info(self):
+        """Get and return schemas added to the publication.
+
+        Returns:
+            List of schemas.
+        """
+        query = ("SELECT n.nspname FROM pg_namespace AS n "
+                 "JOIN pg_publication_namespace AS pn ON n.oid = pn.pnnspid "
+                 "JOIN pg_publication AS p ON p.oid = pn.pnpubid "
+                 "WHERE p.pubname = %(pname)s")
+        list_of_dicts = exec_sql(self, query, query_params={'pname': self.name},
+                                 add_to_executed=False)
+
+        list_of_schemas = []
+        for d in list_of_dicts:
+            list_of_schemas.extend(d.values())
+        return list_of_schemas
+
     def __pub_add_table(self, table, check_mode=False):
         """Add a table to the publication.
 
@@ -528,6 +607,42 @@ class PgPublication():
                                                         ', '.join(quoted_tables)))
         return self.__exec_sql(query, check_mode=check_mode)
 
+    def __pub_add_schema(self, schema, check_mode=False):
+        """Add a schema to the publication.
+
+        Args:
+            schema (str): Schema name.
+
+        Kwargs:
+            check_mode (bool): If True, don't actually change anything,
+                just make SQL, add it to ``self.executed_queries`` and return True.
+
+        Returns:
+            True if truly added, False otherwise.
+        """
+        query = ("ALTER PUBLICATION %s ADD "
+                 "TABLES IN SCHEMA %s" % (pg_quote_identifier(self.name, 'publication'),
+                                          pg_quote_identifier(schema, 'schema')))
+        return self.__exec_sql(query, check_mode=check_mode)
+
+    def __pub_drop_schema(self, schema, check_mode=False):
+        """Drop a schema from the publication.
+
+        Args:
+            schema (str): Schema name.
+
+        Kwargs:
+            check_mode (bool): If True, don't actually change anything,
+                just make SQL, add it to ``self.executed_queries`` and return True.
+
+        Returns:
+            True if truly dropped, False otherwise.
+        """
+        query = ("ALTER PUBLICATION %s DROP "
+                 "TABLES IN SCHEMA %s" % (pg_quote_identifier(self.name, 'publication'),
+                                          pg_quote_identifier(schema, 'schema')))
+        return self.__exec_sql(query, check_mode=check_mode)
+
     def __pub_set_param(self, param, value, check_mode=False):
         """Set an optional publication parameter.
 
@@ -603,10 +718,13 @@ def main():
         cascade=dict(type='bool', default=False),
         session_role=dict(type='str'),
         trust_input=dict(type='bool', default=True),
+        comment=dict(type='str', default=None),
+        tables_in_schema=dict(type='list', elements='str', default=None),
     )
     module = AnsibleModule(
         argument_spec=argument_spec,
         supports_check_mode=True,
+        mutually_exclusive=[('tables', 'tables_in_schema')],
     )
 
     # Parameters handling:
@@ -618,6 +736,8 @@ def main():
     cascade = module.params['cascade']
     session_role = module.params['session_role']
     trust_input = module.params['trust_input']
+    comment = module.params['comment']
+    tables_in_schema = module.params['tables_in_schema']
 
     if not trust_input:
         # Check input for potentially dangerous elements:
@@ -626,7 +746,8 @@ def main():
         else:
             params_list = ['%s = %s' % (k, v) for k, v in iteritems(params)]
 
-        check_input(module, name, tables, owner, session_role, params_list)
+        check_input(module, name, tables, owner,
+                    session_role, params_list, comment)
 
     if state == 'absent':
         if tables:
@@ -639,24 +760,28 @@ def main():
     if state == 'present' and cascade:
         module.warn('parameter "cascade" is ignored when "state=present"')
 
-    # Ensure psycopg2 libraries are available before connecting to DB:
+    # Ensure psycopg libraries are available before connecting to DB:
     ensure_required_libs(module)
     # Connect to DB and make cursor object:
     conn_params = get_conn_params(module, module.params)
     # We check publication state without DML queries execution, so set autocommit:
     db_connection, dummy = connect_to_db(module, conn_params, autocommit=True)
-    cursor = db_connection.cursor(cursor_factory=DictCursor)
+    cursor = db_connection.cursor(**pg_cursor_args)
 
     # Check version:
-    if cursor.connection.server_version < SUPPORTED_PG_VERSION:
+    pg_srv_ver = get_server_version(cursor.connection)
+    if pg_srv_ver < SUPPORTED_PG_VERSION:
         module.fail_json(msg="PostgreSQL server version should be 10.0 or greater")
 
+    if tables_in_schema is not None and pg_srv_ver < 150000:
+        module.fail_json(msg="Publication of tables in schema is supported by PostgreSQL 15 or greater")
+
     # Nothing was changed by default:
     changed = False
 
     ###################################
     # Create object and do rock'n'roll:
-    publication = PgPublication(module, cursor, name)
+    publication = PgPublication(module, cursor, name, pg_srv_ver)
 
     if tables:
         tables = transform_tables_representation(tables)
@@ -664,10 +789,12 @@ def main():
     # If module.check_mode=True, nothing will be changed:
     if state == 'present':
         if not publication.exists:
-            changed = publication.create(tables, params, owner, check_mode=module.check_mode)
+            changed = publication.create(tables, tables_in_schema, params, owner, comment,
+                                         check_mode=module.check_mode)
 
         else:
-            changed = publication.update(tables, params, owner, check_mode=module.check_mode)
+            changed = publication.update(tables, tables_in_schema, params, owner, comment,
+                                         check_mode=module.check_mode)
 
     elif state == 'absent':
         changed = publication.drop(cascade=cascade, check_mode=module.check_mode)
