@@ -142,9 +142,9 @@ EXAMPLES = r"""
       name: "Ansible_Every_Day_Testing"
       type: "every_day"
       hours_of_day:
-        - 8
-        - 14
-      auto_delete: True
+          - 8
+          - 14
+      auto_delete: true
       state: "{{state_present}}"
 
 - name: Create snapshot schedule (Rule Type - every_n_days)
@@ -169,8 +169,8 @@ EXAMPLES = r"""
       name: "Ansible_Every_Week_Testing"
       type: "every_week"
       days_of_week:
-        - MONDAY
-        - FRIDAY
+          - MONDAY
+          - FRIDAY
       hour: 12
       minute: 30
       desired_retention: 200
@@ -185,7 +185,7 @@ EXAMPLES = r"""
       name: "Ansible_Every_Month_Testing"
       type: "every_month"
       day_of_month: 17
-      auto_delete: True
+      auto_delete: true
       state: "{{state_present}}"
 
 - name: Get snapshot schedule details using name
@@ -226,7 +226,7 @@ EXAMPLES = r"""
       name: "Ansible_Every_Day_Testing"
       type: "every_day"
       desired_retention: 200
-      auto_delete: False
+      auto_delete: false
       state: "{{state_present}}"
 
 - name: Delete snapshot schedule using id
@@ -253,7 +253,7 @@ changed:
     description: Whether or not the resource has changed.
     returned: always
     type: bool
-    sample: True
+    sample: true
 
 snapshot_schedule_details:
     description: Details of the snapshot schedule.
@@ -385,14 +385,13 @@ snapshot_schedule_details:
     }
 """
 
-import logging
 from ansible.module_utils.basic import AnsibleModule
 from ansible_collections.dellemc.unity.plugins.module_utils.storage.dell \
     import utils
 
 LOG = utils.get_logger('snapshotschedule')
 
-application_type = "Ansible/1.5.0"
+application_type = "Ansible/1.7.1"
 
 
 class SnapshotSchedule(object):
@@ -519,7 +518,7 @@ class SnapshotSchedule(object):
         LOG.info("Modify Flag: %s", modified)
         return modified
 
-    def get_daysOfWeek_enum(self, days_of_week):
+    def get_days_of_week_enum(self, days_of_week):
         """Get the enum for days of week.
             :param days_of_week: The list of days of week
             :return: The list of days_of_week enum
@@ -589,7 +588,7 @@ class SnapshotSchedule(object):
                                  is_auto_delete=auto_delete)
             elif type == "every_week":
                 if days_of_week:
-                    days_of_week_enum = self.get_daysOfWeek_enum(days_of_week)
+                    days_of_week_enum = self.get_days_of_week_enum(days_of_week)
                 else:
                     days = schedule_details['rules'][0]['days_of_week'][
                         'DayOfWeekEnumList']
@@ -598,7 +597,7 @@ class SnapshotSchedule(object):
                     for day in days:
                         temp = day.split(".")
                         existing_days.append(temp[1])
-                    days_of_week_enum = self.get_daysOfWeek_enum(days_of_week)
+                    days_of_week_enum = self.get_days_of_week_enum(days_of_week)
 
                 rule_dict = utils.snap_schedule.UnitySnapScheduleRule.\
                     every_week(days_of_week=days_of_week_enum, hour=hour,
