@@ -97,7 +97,7 @@ options:
                 description: Deprecated, please rename it to darrp_optimize. Time for running Dynamic Automatic Radio Resource Provisioning
             darrp-optimize-schedules:
                 type: raw
-                description: (list) Deprecated, please rename it to darrp_optimize_schedules.
+                description: (list) Deprecated, please rename it to darrp_optimize_schedules. Firewall schedules for DARRP running time.
             include-dfs-channel:
                 type: str
                 description: Deprecated, please rename it to include_dfs_channel. Enable/disable use of DFS channel in DARRP channel selection phase 1
@@ -312,14 +312,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'arrpprofile'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
