@@ -75,7 +75,9 @@ options:
             flags:
                 type: list
                 elements: str
-                description: No description.
+                description:
+                    - create_task - Create a new task in task manager database.
+                    - nonblocking - The API will return immediately in for non-blocking call.
                 choices:
                     - 'none'
                     - 'create_task'
@@ -83,7 +85,7 @@ options:
                     - 'log_dev'
             from:
                 type: str
-                description: No description.
+                description: From.
                 choices:
                     - 'um'
                     - 'fgfm'
@@ -95,14 +97,14 @@ options:
             reload-dev-member-list:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to reload_dev_member_list.
+                description: Deprecated, please rename it to reload_dev_member_list. Reload dev member list.
                 suboptions:
                     name:
                         type: str
-                        description: No description.
+                        description: Name.
                     vdom:
                         type: str
-                        description: No description.
+                        description: Vdom.
             tag:
                 type: str
                 description: Revision name for the retrieved configuration.
@@ -217,14 +219,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'dvm_cmd_reload_devlist'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_exec(argument_specs=module_arg_spec)
