@@ -89,7 +89,7 @@ options:
             action1:
                 type: list
                 elements: str
-                description: No description.
+                description: Action to take when threshold reached.
                 choices:
                     - 'log'
                     - 'archive'
@@ -100,7 +100,7 @@ options:
             action2:
                 type: list
                 elements: str
-                description: No description.
+                description: Action to take when threshold reached.
                 choices:
                     - 'log'
                     - 'archive'
@@ -111,7 +111,7 @@ options:
             action3:
                 type: list
                 elements: str
-                description: No description.
+                description: Action to take when threshold reached.
                 choices:
                     - 'log'
                     - 'archive'
@@ -318,14 +318,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'firewall_mmsprofile_dupe'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_partial_curd(argument_specs=module_arg_spec)
