@@ -95,14 +95,14 @@ options:
         suboptions:
             end-ip:
                 type: str
-                description: Deprecated, please rename it to end_ip.
+                description: Deprecated, please rename it to end_ip. End ip.
             id:
                 type: int
-                description: No description.
+                description: Id.
                 required: true
             start-ip:
                 type: str
-                description: Deprecated, please rename it to start_ip.
+                description: Deprecated, please rename it to start_ip. Start ip.
             vci-match:
                 type: str
                 description: Deprecated, please rename it to vci_match. Enable/disable vendor class identifier
@@ -111,7 +111,7 @@ options:
                     - 'enable'
             vci-string:
                 type: raw
-                description: (list) Deprecated, please rename it to vci_string.
+                description: (list) Deprecated, please rename it to vci_string. One or more VCI strings in quotes separated by spaces.
             lease-time:
                 type: int
                 description: Deprecated, please rename it to lease_time. Lease time in seconds, 0 means default lease time.
@@ -123,7 +123,7 @@ options:
                     - 'enable'
             uci-string:
                 type: raw
-                description: (list) Deprecated, please rename it to uci_string.
+                description: (list) Deprecated, please rename it to uci_string. One or more UCI strings in quotes separated by spaces.
 '''
 
 EXAMPLES = '''
@@ -241,14 +241,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'fsp_vlan_dhcpserver_excluderange'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
