@@ -1,7 +1,7 @@
 #!/usr/bin/python
 """ this is cifs_server module
 
- (c) 2018-2022, NetApp, Inc
+ (c) 2018-2023, NetApp, Inc
  # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 """
 
@@ -70,6 +70,13 @@ options:
     version_added: 2.7.0
     type: str
 
+  default_site:
+    description:
+      - Specifies the site within the Active Directory domain to associate with the CIFS server if Data ONTAP cannot determine an appropriate site.
+      - Only supported with REST and requires ontap version 9.13.1 or later.
+    version_added: 22.8.0
+    type: str
+
   force:
     type: bool
     description:
@@ -175,6 +182,21 @@ options:
     type: str
     version_added: 21.20.0
 
+  lm_compatibility_level:
+    description:
+      - Specifies CIFS server minimum security level, also known as the LMCompatibilityLevel.
+      - Only supported with REST and requires ontap version 9.8 or later. Use na_ontap_vserver_cifs_security with ZAPI.
+    choices: ['lm_ntlm_ntlmv2_krb', 'ntlm_ntlmv2_krb', 'ntlmv2_krb', 'krb']
+    type: str
+    version_added: 22.9.0
+
+  is_multichannel_enabled:
+    description:
+      - Specifies whether the CIFS server supports Multichannel or not.
+      - Only supported with REST and requires ontap version 9.10 or later.
+    type: bool
+    version_added: 22.10.0
+
 '''
 
 EXAMPLES = '''
@@ -239,16 +261,16 @@ EXAMPLES = '''
         name: data2
         vserver: svm1
         service_state: stopped
-        encrypt_dc_connection: True,
-        smb_encryption: True,
-        kdc_encryption: True,
-        smb_signing: True,
-        aes_netlogon_enabled: True,
-        ldap_referral_enabled: True,
-        session_security: seal,
-        try_ldap_channel_binding: False,
-        use_ldaps: True,
-        use_start_tls": True
+        encrypt_dc_connection: True
+        smb_encryption: True
+        kdc_encryption: True
+        smb_signing: True
+        aes_netlogon_enabled: True
+        ldap_referral_enabled: True
+        session_security: seal
+        try_ldap_channel_binding: False
+        use_ldaps: True
+        use_start_tls: True
         restrict_anonymous: no_access
         domain: "{{ id_domain }}"
         admin_user_name: "{{ domain_login }}"
@@ -289,6 +311,7 @@ class NetAppOntapcifsServer:
             admin_user_name=dict(required=False, type='str'),
             admin_password=dict(required=False, type='str', no_log=True),
             ou=dict(required=False, type='str'),
+            default_site=dict(required=False, type='str'),
             force=dict(required=False, type='bool'),
             vserver=dict(required=True, type='str'),
             from_name=dict(required=False, type='str'),
@@ -300,9 +323,11 @@ class NetAppOntapcifsServer:
             aes_netlogon_enabled=dict(required=False, type='bool'),
             ldap_referral_enabled=dict(required=False, type='bool'),
             session_security=dict(required=False, type='str', choices=['none', 'sign', 'seal']),
+            lm_compatibility_level=dict(required=False, type='str', choices=['lm_ntlm_ntlmv2_krb', 'ntlm_ntlmv2_krb', 'ntlmv2_krb', 'krb']),
             try_ldap_channel_binding=dict(required=False, type='bool'),
             use_ldaps=dict(required=False, type='bool'),
-            use_start_tls=dict(required=False, type='bool')
+            use_start_tls=dict(required=False, type='bool'),
+            is_multichannel_enabled=dict(required=False, type='bool'),
         ))
 
         self.module = AnsibleModule(
@@ -318,18 +343,19 @@ class NetAppOntapcifsServer:
         # Set up Rest API
         self.rest_api = OntapRestAPI(self.module)
         unsupported_rest_properties = ['workgroup']
-        partially_supported_rest_properties = [['encrypt_dc_connection', (9, 8)], ['aes_netlogon_enabled', (9, 10, 1)], ['ldap_referral_enabled', (9, 10, 1)],
-                                               ['session_security', (9, 10, 1)], ['try_ldap_channel_binding', (9, 10, 1)], ['use_ldaps', (9, 10, 1)],
-                                               ['use_start_tls', (9, 10, 1)], ['force', (9, 11)]]
+        partially_supported_rest_properties = [['encrypt_dc_connection', (9, 8)], ['lm_compatibility_level', (9, 8)],
+                                               ['aes_netlogon_enabled', (9, 10, 1)], ['ldap_referral_enabled', (9, 10, 1)], ['session_security', (9, 10, 1)],
+                                               ['try_ldap_channel_binding', (9, 10, 1)], ['use_ldaps', (9, 10, 1)], ['use_start_tls', (9, 10, 1)],
+                                               ['is_multichannel_enabled', (9, 10, 1)], ['force', (9, 11)], ['default_site', (9, 13, 1)]]
         self.use_rest = self.rest_api.is_rest_supported_properties(self.parameters, unsupported_rest_properties, partially_supported_rest_properties)
 
         if not self.use_rest:
             unsupported_zapi_properties = ['smb_signing', 'encrypt_dc_connection', 'kdc_encryption', 'smb_encryption', 'restrict_anonymous',
                                            'aes_netlogon_enabled', 'ldap_referral_enabled', 'try_ldap_channel_binding', 'session_security',
-                                           'use_ldaps', 'use_start_tls']
+                                           'lm_compatibility_level', 'use_ldaps', 'use_start_tls', 'from_name', 'default_site', 'is_multichannel_enabled']
             used_unsupported_zapi_properties = [option for option in unsupported_zapi_properties if option in self.parameters]
             if used_unsupported_zapi_properties:
-                self.module.fail_json(msg="Error: %s options supported only with REST." % " ,".join(unsupported_zapi_properties))
+                self.module.fail_json(msg="Error: %s options supported only with REST." % " ,".join(used_unsupported_zapi_properties))
             if not netapp_utils.has_netapp_lib():
                 self.module.fail_json(msg=netapp_utils.netapp_lib_is_required())
             self.server = netapp_utils.setup_na_ontap_zapi(module=self.module, vserver=self.parameters['vserver'])
@@ -358,19 +384,20 @@ class NetAppOntapcifsServer:
 
             cifs_server_attributes = result.get_child_by_name('attributes-list').\
                 get_child_by_name('cifs-server-config')
+            service_state = cifs_server_attributes.get_child_content('administrative-status')
             return_value = {
                 'cifs_server_name': self.parameters['cifs_server_name'],
-                'administrative-status': cifs_server_attributes.get_child_content('administrative-status')
+                'service_state': 'started' if service_state == 'up' else 'stopped'
             }
-
         return return_value
 
     def create_cifs_server(self):
         """
         calling zapi to create cifs_server
         """
-        options = {'cifs-server': self.parameters['cifs_server_name'], 'administrative-status': 'up'
-                   if self.parameters.get('service_state') == 'started' else 'down'}
+        options = {'cifs-server': self.parameters['cifs_server_name']}
+        if 'service_state' in self.parameters:
+            options['administrative-status'] = 'up' if self.parameters['service_state'] == 'started' else 'down'
         if 'workgroup' in self.parameters:
             options['workgroup'] = self.parameters['workgroup']
         if 'domain' in self.parameters:
@@ -447,6 +474,8 @@ class NetAppOntapcifsServer:
         """
         get details of the cifs_server.
         """
+        if not self.use_rest:
+            return self.get_cifs_server()
         query = {'svm.name': self.parameters['vserver'],
                  'fields': 'svm.uuid,'
                            'enabled,'
@@ -457,7 +486,9 @@ class NetAppOntapcifsServer:
         query['name'] = from_name or self.parameters['cifs_server_name']
         api = 'protocols/cifs/services'
         if self.rest_api.meets_rest_minimum_version(self.use_rest, 9, 8):
-            query['fields'] += 'security.encrypt_dc_connection,'
+            security_option_9_8 = ('security.encrypt_dc_connection,'
+                                   'security.lm_compatibility_level,')
+            query['fields'] += security_option_9_8
 
         if self.rest_api.meets_rest_minimum_version(self.use_rest, 9, 10, 1):
             security_option_9_10 = ('security.use_ldaps,'
@@ -467,6 +498,10 @@ class NetAppOntapcifsServer:
                                     'security.ldap_referral_enabled,'
                                     'security.aes_netlogon_enabled,')
             query['fields'] += security_option_9_10
+
+        if self.rest_api.meets_rest_minimum_version(self.use_rest, 9, 10, 1):
+            service_option_9_10 = ('options.multichannel,')
+            query['fields'] += service_option_9_10
         record, error = rest_generic.get_one_record(self.rest_api, api, query)
         if error:
             self.module.fail_json(msg="Error on fetching cifs: %s" % error)
@@ -474,7 +509,7 @@ class NetAppOntapcifsServer:
             record['service_state'] = 'started' if record.pop('enabled') else 'stopped'
             return {
                 'svm': {'uuid': self.na_helper.safe_get(record, ['svm', 'uuid'])},
-                'name': self.na_helper.safe_get(record, ['name']),
+                'cifs_server_name': self.na_helper.safe_get(record, ['name']),
                 'service_state': self.na_helper.safe_get(record, ['service_state']),
                 'smb_signing': self.na_helper.safe_get(record, ['security', 'smb_signing']),
                 'encrypt_dc_connection': self.na_helper.safe_get(record, ['security', 'encrypt_dc_connection']),
@@ -483,19 +518,15 @@ class NetAppOntapcifsServer:
                 'aes_netlogon_enabled': self.na_helper.safe_get(record, ['security', 'aes_netlogon_enabled']),
                 'ldap_referral_enabled': self.na_helper.safe_get(record, ['security', 'ldap_referral_enabled']),
                 'session_security': self.na_helper.safe_get(record, ['security', 'session_security']),
+                'lm_compatibility_level': self.na_helper.safe_get(record, ['security', 'lm_compatibility_level']),
                 'try_ldap_channel_binding': self.na_helper.safe_get(record, ['security', 'try_ldap_channel_binding']),
                 'use_ldaps': self.na_helper.safe_get(record, ['security', 'use_ldaps']),
                 'use_start_tls': self.na_helper.safe_get(record, ['security', 'use_start_tls']),
-                'restrict_anonymous': self.na_helper.safe_get(record, ['security', 'restrict_anonymous'])
+                'restrict_anonymous': self.na_helper.safe_get(record, ['security', 'restrict_anonymous']),
+                'is_multichannel_enabled': self.na_helper.safe_get(record, ['options', 'multichannel']),
             }
         return record
 
-    def service_state_to_bool(self, modify=None):
-        if modify and 'service_state' in modify:
-            return modify['service_state'] == 'started'
-        else:
-            return self.parameters.get('service_state') == 'started'
-
     def build_ad_domain(self):
         ad_domain = {}
         if 'admin_user_name' in self.parameters:
@@ -506,38 +537,53 @@ class NetAppOntapcifsServer:
             ad_domain['organizational_unit'] = self.parameters['ou']
         if 'domain' in self.parameters:
             ad_domain['fqdn'] = self.parameters['domain']
+        if 'default_site' in self.parameters:
+            ad_domain['default_site'] = self.parameters['default_site']
         return ad_domain
 
-    def create_modify_body_rest(self, body, modify=None):
+    def create_modify_body_rest(self, params=None):
         """
         Function to define body for create and modify cifs server
         """
+        body, query, security, service_options = {}, {}, {}, {}
+        if params is None:
+            params = self.parameters
         security_options = ['smb_signing', 'encrypt_dc_connection', 'kdc_encryption', 'smb_encryption', 'restrict_anonymous',
-                            'aes_netlogon_enabled', 'ldap_referral_enabled', 'try_ldap_channel_binding', 'session_security', 'use_ldaps', 'use_start_tls']
+                            'aes_netlogon_enabled', 'ldap_referral_enabled', 'try_ldap_channel_binding', 'session_security',
+                            'lm_compatibility_level', 'use_ldaps', 'use_start_tls']
         ad_domain = self.build_ad_domain()
         if ad_domain:
             body['ad_domain'] = ad_domain
-        query = {}
         if 'force' in self.parameters:
             query['force'] = self.parameters['force']
-        security = {}
         for key in security_options:
-            if not modify and key in self.parameters:
-                security[key] = self.parameters[key]
-            elif modify and key in modify:
-                security[key] = modify[key]
+            if key in params:
+                security[key] = params[key]
         if security:
             body['security'] = security
+        # for parameters having different key names in REST API and module inputs
+        for key, option in [
+            ('multichannel', 'is_multichannel_enabled'),
+        ]:
+            if option in params:
+                service_options.update({key: params[option]})
+        if service_options:
+            body['options'] = service_options
+        if 'vserver' in params:
+            body['svm.name'] = params['vserver']
+        if 'cifs_server_name' in params:
+            body['name'] = self.parameters['cifs_server_name']
+        if 'service_state' in params:
+            body['enabled'] = params['service_state'] == 'started'
         return body, query
 
     def create_cifs_server_rest(self):
         """
         create the cifs_server.
         """
-        body = {'svm.name': self.parameters['vserver'],
-                'name': self.parameters['cifs_server_name'],
-                'enabled': self.service_state_to_bool()}
-        body, query = self.create_modify_body_rest(body)
+        if not self.use_rest:
+            return self.create_cifs_server()
+        body, query = self.create_modify_body_rest()
         api = 'protocols/cifs/services'
         dummy, error = rest_generic.post_async(self.rest_api, api, body, query)
         if error is not None:
@@ -547,6 +593,8 @@ class NetAppOntapcifsServer:
         """
         delete the cifs_server.
         """
+        if not self.use_rest:
+            return self.delete_cifs_server()
         ad_domain = self.build_ad_domain()
         body = {'ad_domain': ad_domain} if ad_domain else None
         query = {}
@@ -562,91 +610,49 @@ class NetAppOntapcifsServer:
         Modify the state of CIFS server.
         rename: cifs server should be in stopped state
         """
-        body = {}
-        body, query = self.create_modify_body_rest(body, modify)
-        body['enabled'] = self.service_state_to_bool(modify)
-        if 'name' in modify:
-            body['name'] = self.parameters['name']
+        if not self.use_rest:
+            return self.modify_cifs_server()
+        body, query = self.create_modify_body_rest(modify)
         api = 'protocols/cifs/services'
         dummy, error = rest_generic.patch_async(self.rest_api, api, current['svm']['uuid'], body, query)
         if error is not None:
             self.module.fail_json(msg="Error on modifying cifs server: %s" % error)
 
-    def zapiapply(self):
+    def modify_cifs_server(self):
         """
-        calling all cifs_server features
+        Start or stop cifs server in ZAPI.
         """
-
-        changed = False
-        cifs_server_exists = False
-        netapp_utils.ems_log_event("na_ontap_cifs_server", self.server)
-        cifs_server_detail = self.get_cifs_server()
-
-        if cifs_server_detail:
-            cifs_server_exists = True
-
-            if self.parameters['state'] == 'present':
-                administrative_status = cifs_server_detail['administrative-status']
-                if self.parameters.get('service_state') == 'started' and administrative_status == 'down':
-                    changed = True
-                if self.parameters.get('service_state') == 'stopped' and administrative_status == 'up':
-                    changed = True
-            else:
-                # we will delete the CIFs server
-                changed = True
-        elif self.parameters['state'] == 'present':
-            changed = True
-
-        if changed and not self.module.check_mode:
-            if self.parameters['state'] == 'present':
-                if not cifs_server_exists:
-                    self.create_cifs_server()
-
-                elif self.parameters.get('service_state') == 'stopped':
-                    self.stop_cifs_server()
-
-                elif self.parameters.get('service_state') == 'started':
-                    self.start_cifs_server()
-
-            elif self.parameters['state'] == 'absent':
-                self.delete_cifs_server()
-
-        self.module.exit_json(changed=changed)
+        if self.parameters.get('service_state') == 'stopped':
+            self.stop_cifs_server()
+        else:
+            self.start_cifs_server()
 
     def apply(self):
-        if not self.use_rest:
-            self.zapiapply()
         current = self.get_cifs_server_rest()
-        cd_action, rename = None, None
-        modify = None
         cd_action = self.na_helper.get_cd_action(current, self.parameters)
         if cd_action == 'create' and 'from_name' in self.parameters:
-            cifs_info = self.get_cifs_server_rest(self.parameters['from_name'])
-            rename = self.na_helper.is_rename_action(cifs_info, current)
-            if rename is None:
+            current = self.get_cifs_server_rest(self.parameters['from_name'])
+            if current is None:
                 self.module.fail_json(msg='Error renaming cifs server: %s - no cifs server with from_name: %s.'
                                       % (self.parameters['name'], self.parameters['from_name']))
-            elif rename:
-                if 'force' in self.parameters and self.parameters.get('force') is True:
-                    current = cifs_info
-                    cd_action = None
-                else:
-                    self.module.fail_json(msg='Error renaming cifs server from %s to %s without force.'
-                                          % (self.parameters['from_name'], self.parameters['name']))
+            if not self.parameters.get('force'):
+                self.module.fail_json(msg='Error: cannot rename cifs server from %s to %s without force.'
+                                      % (self.parameters['from_name'], self.parameters['name']))
+            # rename is handled in modify in REST.
+            cd_action = None
         modify = self.na_helper.get_modified_attributes(current, self.parameters) if cd_action is None else None
         if self.na_helper.changed and not self.module.check_mode:
-            if rename:
-                current['name'] = self.parameters.get('name')
-                self.modify_cifs_server_rest(current, modify)
-
             if cd_action == 'create':
                 self.create_cifs_server_rest()
             elif cd_action == 'delete':
                 self.delete_cifs_server_rest(current)
-
-            if modify:
+            else:
                 self.modify_cifs_server_rest(current, modify)
-        self.module.exit_json(changed=self.na_helper.changed)
+                # rename will enable the cifs server also, so disable it if service_state is stopped.
+                if 'cifs_server_name' in modify and self.parameters.get('service_state') == 'stopped':
+                    self.modify_cifs_server_rest(current, {'service_state': 'stopped'})
+        result = netapp_utils.generate_result(self.na_helper.changed, cd_action, modify)
+        self.module.exit_json(**result)
 
 
 def main():
