@@ -433,8 +433,6 @@ class NetAppOntapUnixGroup:
 
         :return: None
         """
-        if not self.use_rest:
-            netapp_utils.ems_log_event("na_ontap_unix_user_group", self.server)
         cd_action = None
         current = self.get_unix_group_rest()
         if current and current['users'] is None:
@@ -448,7 +446,8 @@ class NetAppOntapUnixGroup:
                 self.delete_unix_group_rest(current)
             else:
                 self.modify_unix_group_rest(modify, current)
-        self.module.exit_json(changed=self.na_helper.changed)
+        result = netapp_utils.generate_result(self.na_helper.changed, cd_action, modify)
+        self.module.exit_json(**result)
 
 
 def main():
