@@ -11,7 +11,7 @@ short_description: Resource module for Pnp Device Authorize
 description:
 - Manage operation create of the resource Pnp Device Authorize.
 - Authorizes one of more devices. A device can only be authorized if Authorization is set in Device Settings.
-version_added: '6.5.0'
+version_added: '6.0.0'
 extends_documentation_fragment:
   - cisco.dnac.module
 author: Rafael Campos (@racampos)
@@ -21,15 +21,15 @@ options:
     elements: str
     type: list
 requirements:
-- dnacentersdk >= 2.5.5
+- dnacentersdk >= 2.7.2
 - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for  AuthorizeDevice
+- name: Cisco DNA Center documentation for Device Onboarding (PnP) AuthorizeDevice
   description: Complete reference of the AuthorizeDevice API.
   link: https://developer.cisco.com/docs/dna-center/#!authorize-device
 notes:
   - SDK Method used are
-    ..authorize_device,
+    device_onboarding_pnp.DeviceOnboardingPnp.authorize_device,
 
   - Paths used are
     post /api/v1/onboarding/pnp-device/authorize,
@@ -50,7 +50,6 @@ EXAMPLES = r"""
     - string
 
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
