@@ -425,12 +425,8 @@ class PnP(DnacBase):
         response = None
 
         try:
-            response = self.dnac_apply['exec'](
-                family="sites",
-                function='get_site',
-                params={"name": self.want.get("site_name")},
-                op_modifies=True,
-            )
+            response = self.get_site(self.want.get("site_name"))
+
         except Exception:
             self.log("Exception occurred as site \
                 '{0}' was not found".format(self.want.get("site_name")), "CRITICAL")
@@ -464,12 +460,7 @@ class PnP(DnacBase):
         """
 
         try:
-            response = self.dnac_apply['exec'](
-                family="sites",
-                function='get_site',
-                params={"name": self.want.get("site_name")},
-                op_modifies=True,
-            )
+            response = self.get_site(self.want.get("site_name"))
         except Exception:
             self.log("Exception occurred as \
                 site '{0}' was not found".format(self.want.get("site_name")), "CRITICAL")
@@ -697,16 +688,11 @@ class PnP(DnacBase):
         # Claiming is only allowed for single addition of devices
         if len(self.want.get('pnp_params')) == 1:
             # check if given device exists in pnp inventory, store device Id
-            device_response = self.dnac_apply['exec'](
-                family="device_onboarding_pnp",
-                function='get_device_list',
-                params={"serial_number": self.want.get("serial_number")},
-                op_modifies=True,
-            )
+            device_response = self.get_device_list_pnp(self.want.get("serial_number"))
             self.log("Device details for the device with serial \
-                number '{0}': {1}".format(self.want.get("serial_number"), str(device_response)), "DEBUG")
+                number '{0}': {1}".format(self.want.get("serial_number"), self.pprint(device_response)), "DEBUG")
 
-            if not (device_response and (len(device_response) == 1)):
+            if not device_response:
                 self.log("Device with serial number {0} is not found in the inventory".format(self.want.get("serial_number")), "WARNING")
                 self.msg = "Adding the device to database"
                 self.status = "success"
@@ -715,7 +701,7 @@ class PnP(DnacBase):
                 return self
 
             have["device_found"] = True
-            have["device_id"] = device_response[0].get("id")
+            have["device_id"] = device_response.get("id")
             self.log("Device Id: " + str(have["device_id"]))
 
             if self.params.get("state") == "merged":
@@ -724,29 +710,27 @@ class PnP(DnacBase):
                     family="software_image_management_swim",
                     function='get_software_image_details',
                     params=self.want.get("image_params"),
-                    op_modifies=True,
                 )
                 image_list = image_response.get("response")
-                self.log("Image details obtained from the API 'get_software_image_details': {0}".format(str(image_response)), "DEBUG")
+                self.log("Image details obtained from the API 'get_software_image_details': {0}"
+                         .format(self.pprint(image_response)), "DEBUG")
 
                 # check if project has templates or not
                 template_list = self.dnac_apply['exec'](
                     family="configuration_templates",
                     function='gets_the_templates_available',
                     params={"project_names": self.want.get("project_name")},
-                    op_modifies=True,
                 )
-                self.log("List of templates under the project '{0}': {1}".format(self.want.get("project_name"), str(template_list)), "DEBUG")
+                self.log("List of templates under the project '{0}': {1}"
+                         .format(self.want.get("project_name"), self.pprint(template_list)), "DEBUG")
+
+                dev_details_response = self.get_device_by_id_pnp(device_response.get("id"))
+                self.log("Device details retrieved after calling the 'get_device_by_id' API: {0}"
+                         .format(self.pprint(dev_details_response)), "DEBUG")
 
-                dev_details_response = self.dnac_apply['exec'](
-                    family="device_onboarding_pnp",
-                    function="get_device_by_id",
-                    params={"id": device_response[0].get("id")},
-                    op_modifies=True,
-                )
-                self.log("Device details retrieved after calling the 'get_device_by_id' API: {0}".format(str(dev_details_response)), "DEBUG")
                 install_mode = dev_details_response.get("deviceInfo").get("mode")
-                self.log("Installation mode of the device with the serial no. '{0}':{1}".format(self.want.get("serial_number"), install_mode), "INFO")
+                self.log("Installation mode of the device with the serial no. '{0}':{1}"
+                         .format(self.want.get("serial_number"), install_mode), "INFO")
 
                 # check if given site exits, if exists store current site info
                 site_exists = False
@@ -902,14 +886,10 @@ class PnP(DnacBase):
         if len(self.want.get("pnp_params")) > 1:
             devices_added = []
             for device in self.want.get("pnp_params"):
-                multi_device_response = self.dnac_apply['exec'](
-                    family="device_onboarding_pnp",
-                    function='get_device_list',
-                    params={"serial_number": device["deviceInfo"]["serialNumber"]},
-                    op_modifies=True,
-                )
+                multi_device_response = self.get_device_list_pnp(device["deviceInfo"]["serialNumber"])
                 self.log("Device details for serial number {0} \
-                        obtained from the API 'get_device_list': {1}".format(device["deviceInfo"]["serialNumber"], str(multi_device_response)), "DEBUG")
+                        obtained from the API 'get_device_list': {1}".format(device["deviceInfo"]["serialNumber"],
+                                                                             str(multi_device_response)), "DEBUG")
                 if (multi_device_response and (len(multi_device_response) == 1)):
                     devices_added.append(device)
                     self.log("Details of the added device:{0}".format(str(device)), "INFO")
@@ -964,22 +944,16 @@ class PnP(DnacBase):
 
             if not self.want["site_name"]:
                 self.log("Adding device to pnp database", "INFO")
-                dev_add_response = self.dnac_apply['exec'](
-                    family="device_onboarding_pnp",
-                    function="add_device",
-                    params=self.want.get('pnp_params')[0],
-                    op_modifies=True,
-                )
-
+                dev_add_response = self.add_pnp_device(self.want.get('pnp_params')[0])
                 self.have["deviceInfo"] = dev_add_response.get("deviceInfo")
                 self.log("Response from API 'add device' for a single device addition: {0}".format(str(dev_add_response)), "DEBUG")
+
                 if self.have["deviceInfo"]:
                     self.result['msg'] = "Only Device Added Successfully"
                     self.log(self.result['msg'], "INFO")
                     self.result['response'] = dev_add_response
                     self.result['diff'] = self.validated_config
                     self.result['changed'] = True
-
                 else:
                     self.msg = "Device Addition Failed"
                     self.log(self.result['msg'], "CRITICAL")
@@ -989,25 +963,16 @@ class PnP(DnacBase):
 
             else:
                 self.log("Adding device to pnp database")
-                dev_add_response = self.dnac_apply['exec'](
-                    family="device_onboarding_pnp",
-                    function="add_device",
-                    params=self.want.get("pnp_params")[0],
-                    op_modifies=True,
-                )
+                dev_add_response = self.add_pnp_device(self.want.get('pnp_params')[0])
                 self.get_have().check_return_status()
                 self.have["deviceInfo"] = dev_add_response.get("deviceInfo")
                 self.log("Response from API 'add device' for single device addition: {0}".format(str(dev_add_response)), "DEBUG")
                 claim_params = self.get_claim_params()
                 claim_params["deviceId"] = dev_add_response.get("id")
-                claim_response = self.dnac_apply['exec'](
-                    family="device_onboarding_pnp",
-                    function='claim_a_device_to_a_site',
-                    op_modifies=True,
-                    params=claim_params,
-                )
 
-                self.log("Response from API 'claim a device to a site' for a single claiming: {0}".format(str(dev_add_response)), "DEBUG")
+                claim_response = self.claim_device_site(claim_params)
+                self.log("Response from API 'claim a device to a site' for a single claiming: {0}".format(str(claim_response)), "DEBUG")
+
                 if claim_response.get("response") == "Device Claimed" and self.have["deviceInfo"]:
                     self.result['msg'] = "Device Added and Claimed Successfully"
                     self.log(self.result['msg'], "INFO")
@@ -1022,28 +987,13 @@ class PnP(DnacBase):
 
                 return self
 
-        prov_dev_response = self.dnac_apply['exec'](
-            family="device_onboarding_pnp",
-            function='get_device_count',
-            op_modifies=True,
-            params=provisioned_count_params,
-        )
+        prov_dev_response = self.pnp_device_count(provisioned_count_params)
         self.log("Response from 'get device count' API for provisioned devices: {0}".format(str(prov_dev_response)), "DEBUG")
 
-        plan_dev_response = self.dnac_apply['exec'](
-            family="device_onboarding_pnp",
-            function='get_device_count',
-            op_modifies=True,
-            params=planned_count_params,
-        )
+        plan_dev_response = self.pnp_device_count(planned_count_params)
         self.log("Response from 'get_device_count' API for devices in planned state: {0}".format(str(plan_dev_response)), "DEBUG")
 
-        dev_details_response = self.dnac_apply['exec'](
-            family="device_onboarding_pnp",
-            function="get_device_by_id",
-            params={"id": self.have["device_id"]},
-            op_modifies=True,
-        )
+        dev_details_response = self.get_device_by_id_pnp(self.have["device_id"])
         self.log("Response from 'get_device_by_id' API for device details: {0}".format(str(dev_details_response)), "DEBUG")
 
         is_stack = False
@@ -1103,13 +1053,9 @@ class PnP(DnacBase):
         claim_params = self.get_claim_params()
         self.log("Parameters for claiming the device: {0}".format(str(claim_params)), "DEBUG")
 
-        claim_response = self.dnac_apply['exec'](
-            family="device_onboarding_pnp",
-            function='claim_a_device_to_a_site',
-            op_modifies=True,
-            params=claim_params,
-        )
+        claim_response = self.claim_device_site(claim_params)
         self.log("Response from 'claim_a_device_to_a_site' API for claiming: {0}".format(str(claim_response)), "DEBUG")
+
         if claim_response.get("response") == "Device Claimed":
             self.result['msg'] = "Only Device Claimed Successfully"
             self.log(self.result['msg'], "INFO")
@@ -1138,15 +1084,11 @@ class PnP(DnacBase):
         devices_deleted = []
         devices_to_delete = self.want.get("pnp_params")[:]
         for device in devices_to_delete:
-            multi_device_response = self.dnac_apply['exec'](
-                family="device_onboarding_pnp",
-                function='get_device_list',
-                params={"serial_number": device["deviceInfo"]["serialNumber"]},
-                op_modifies=True,
-            )
+            multi_device_response = self.get_device_list_pnp(device["deviceInfo"]["serialNumber"])
             self.log("Response from 'get_device_list' API for claiming: {0}".format(str(multi_device_response)), "DEBUG")
-            if multi_device_response and len(multi_device_response) == 1:
-                device_id = multi_device_response[0].get("id")
+
+            if multi_device_response:
+                device_id = multi_device_response.get("id")
 
                 response = self.dnac_apply['exec'](
                     family="device_onboarding_pnp",
@@ -1191,24 +1133,18 @@ class PnP(DnacBase):
             logs the states, and validates whether the specified device(s) exists in the DNA
             Center configuration's PnP Database.
         """
-
         self.log("Current State (have): {0}".format(str(self.have)), "INFO")
         self.log("Desired State (want): {0}".format(str(config)), "INFO")
         # Code to validate Cisco Catalyst Center config for merged state
         for device in self.want.get("pnp_params"):
-            device_response = self.dnac_apply['exec'](
-                family="device_onboarding_pnp",
-                function='get_device_list',
-                params={"serial_number": device["deviceInfo"]["serialNumber"]},
-                op_modifies=True,
-            )
+            device_response = self.get_device_list_pnp(device["deviceInfo"]["serialNumber"])
+
             if (device_response and (len(device_response) == 1)):
                 msg = (
                     "Requested Device with Serial No. {0} is "
                     "present in Cisco Catalyst Center and"
                     " addition verified.".format(device["deviceInfo"]["serialNumber"]))
                 self.log(msg, "INFO")
-
             else:
                 msg = (
                     "Requested Device with Serial No. {0} is "
@@ -1232,24 +1168,18 @@ class PnP(DnacBase):
             It validates whether the specified device(s) exists in the Cisco Catalyst Center configuration's
             PnP Database.
         """
-
         self.log("Current State (have): {0}".format(str(self.have)), "INFO")
         self.log("Desired State (want): {0}".format(str(config)), "INFO")
         # Code to validate Cisco Catalyst Center config for deleted state
         for device in self.want.get("pnp_params"):
-            device_response = self.dnac_apply['exec'](
-                family="device_onboarding_pnp",
-                function='get_device_list',
-                params={"serial_number": device["deviceInfo"]["serialNumber"]},
-                op_modifies=True,
-            )
+            device_response = self.get_device_list_pnp(device["deviceInfo"]["serialNumber"])
+
             if not (device_response and (len(device_response) == 1)):
                 msg = (
                     "Requested Device with Serial No. {0} is "
                     "not present in the Cisco DNA"
                     "Center.".format(device["deviceInfo"]["serialNumber"]))
                 self.log(msg, "INFO")
-
             else:
                 msg = (
                     "Requested Device with Serial No. {0} is "
@@ -1259,6 +1189,186 @@ class PnP(DnacBase):
         self.status = "success"
         return self
 
+    def get_device_list_pnp(self, serial_number):
+        """
+        Get the PNP device list from the Cisco Catalyst Center.
+
+        Parameters:
+          - self (object): An instance of the class containing the method.
+          - serial_number (str): Serial number contains string from the device data.
+        Returns:
+          The method returns an instance of the class with updated attributes:
+          - self.device_response: Gets the device_id and stores it
+
+        Example:
+          passing device details and getting pnp device details response
+        """
+        try:
+            response = self.dnac_apply['exec'](
+                family="device_onboarding_pnp",
+                function='get_device_list',
+                params={"serial_number": serial_number},
+            )
+
+            if response and isinstance(response, list) and len(response) == 1:
+                self.device_response = response[0]
+                self.log("Successfully retrieved PNP device details for serial number: {0}".format(serial_number), "INFO")
+                return self.device_response
+
+            msg = "No device found with serial number: {0}".format(serial_number)
+            self.log(msg, "WARNING")
+            return None
+
+        except Exception as e:
+            msg = "An error occurred while retrieving device with serial number {0}: {1}".format(serial_number, str(e))
+            self.log(msg + str(e), "WARNING")
+            self.module.fail_json(msg=msg)
+
+    def get_device_by_id_pnp(self, device_id):
+        """
+        Get the PNP device details using by device id from the Cisco Catalyst Center.
+
+        Parameters:
+        - self (object): An instance of the class containing the method.
+        - device_id (str): Device id contains id from the device data
+        Returns:
+        The method returns an instance of the class with updated attributes:
+        - self.device_response: Gets the device_id and stores it
+
+        Example:
+        passing device details and getting pnp device details response
+        """
+        self.log("Attempting to retrieve PNP device details for device id: {0}".format(device_id), "INFO")
+        try:
+            device_details_response = self.dnac_apply['exec'](
+                family="device_onboarding_pnp",
+                function="get_device_by_id",
+                params={"id": device_id},
+            )
+            # Check if the response contains the expected data
+            if device_details_response:
+                self.device_response = device_details_response  # Update the instance attribute
+                self.log("Successfully retrieved PNP device details for device id: {0}".format(device_id), "INFO")
+                return self.device_response
+
+            # If no device found, raise an error
+            msg = "No device found with device id: {0}".format(device_id)
+            self.log(msg, "WARNING")
+            self.module.fail_json(msg=msg)
+
+        except Exception as e:
+            msg = "An error occurred while retrieving device with device id {0}: {1}".format(device_id, str(e))
+            self.log(msg + str(e), "WARNING")
+            self.module.fail_json(msg=msg)
+
+    def add_pnp_device(self, pnp_params):
+        """
+        Add the PNP device in the Cisco Catalyst Center.
+
+        Parameters:
+        - self (object): An instance of the class containing the method.
+        - pnp_params (dict): Device infomation to add in the inventry
+        Returns:
+        The method returns an instance of the class with updated attributes:
+        - self.device_response: Gets the device_id and stores it
+
+        Example:
+        passing device details and getting pnp device details response
+        """
+        self.log("Attempting to add PNP device with parameters: {0}".format(pnp_params), "INFO")
+        try:
+            device_add_response = self.dnac_apply['exec'](
+                family="device_onboarding_pnp",
+                function="add_device",
+                params=pnp_params,
+                op_modifies=True,
+            )
+            if device_add_response:
+                self.device_response = device_add_response  # Update the instance attribute
+                self.log("Successfully added PNP device with parameters: {0}".format(pnp_params), "INFO")
+                return self.device_response
+
+            # If the response is empty, log a warning
+            msg = "No response received when trying to add the PNP device with parameters: {0}".format(pnp_params)
+            self.log(msg, "WARNING")
+            self.module.fail_json(msg=msg)
+
+        except Exception as e:
+            msg = "Unable to add the PNP device with parameters: {0}. Error: {1}".format(pnp_params, str(e))
+            self.log(msg + str(e), "WARNING")
+            self.module.fail_json(msg=msg)
+
+    def pnp_device_count(self, pnp_params):
+        """
+        Get the PNP device count from the Cisco Catalyst Center.
+
+        Parameters:
+            - self (object): An instance of the class containing the method.
+            - pnp_params (dict): Device infomation to get the pnp device fields
+        Returns:
+            The method returns an instance of the class with count attributes:
+            - prov_dev_response: Show the count of the pnp devices
+
+        Example:
+            passing device param and getting pnp device count response
+        """
+        self.log("Attempting to get PNP device count with parameters: {0}".format(pnp_params), "INFO")
+        try:
+            prov_dev_response = self.dnac_apply['exec'](
+                family="device_onboarding_pnp",
+                function='get_device_count',
+                params=pnp_params,
+            )
+            if prov_dev_response:
+                self.log("Successfully retrieved PNP device count: {0}".format(prov_dev_response), "INFO")
+                return prov_dev_response
+
+            # If the response is empty, log a warning
+            msg = "No response received when trying to get the PNP device count for parameters: {0}".format(pnp_params)
+            self.log(msg, "WARNING")
+            self.module.fail_json(msg=msg)
+
+        except Exception as e:
+            msg = "Unable to get the PNP device count for parameters: {0}. Error: {1}".format(pnp_params, str(e))
+            self.log(msg + str(e), "WARNING")
+            self.module.fail_json(msg=msg)
+
+    def claim_device_site(self, claim_params):
+        """
+        Claim the PNP device from the Cisco Catalyst Center.
+
+        Parameters:
+            - self (object): An instance of the class containing the method.
+            - claim_params (dict): Device infomation to get the pnp device fields
+        Returns:
+            The method returns an instance of the class with count attributes:
+            - claim_response: Show the count of the pnp devices
+
+        Example:
+            passing device claim param and getting pnp claim response
+        """
+        self.log("Attempting to claim device to site with parameters: {0}".format(claim_params), "INFO")
+        try:
+            claim_response = self.dnac_apply['exec'](
+                family="device_onboarding_pnp",
+                function='claim_a_device_to_a_site',
+                op_modifies=True,
+                params=claim_params,
+            )
+            if claim_response:
+                self.log("Successfully claimed device to site: {0}".format(claim_response), "INFO")
+                return claim_response
+
+            # If the response is empty, log a warning
+            msg = "No response received when trying to claim the device to site with parameters: {0}".format(claim_params)
+            self.log(msg, "WARNING")
+            self.module.fail_json(msg=msg)
+
+        except Exception as e:
+            msg = "Unable to claim the device to site with parameters: {0}. Error: {1}".format(claim_params, str(e))
+            self.log(msg + str(e), "WARNING")
+            self.module.fail_json(msg=msg)
+
 
 def main():
     """
