@@ -10,7 +10,7 @@ module: service_provider_create
 short_description: Resource module for Service Provider Create
 description:
 - Manage operation create of the resource Service Provider Create.
-- API to create service provider profile QOS .
+- API to create Service Provider Profile QOS .
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module
@@ -35,7 +35,7 @@ options:
         type: list
     type: dict
 requirements:
-- dnacentersdk >= 2.5.5
+- dnacentersdk >= 2.7.2
 - python >= 3.5
 seealso:
 - name: Cisco DNA Center documentation for Network Settings CreateSPProfile
@@ -67,7 +67,6 @@ EXAMPLES = r"""
         wanProvider: string
 
 """
-
 RETURN = r"""
 dnac_response:
   description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
