@@ -16,11 +16,21 @@ the given network resource.
 """
 import re
 
+from ansible.module_utils._text import to_text
 from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.network_template import (
     NetworkTemplate,
 )
 
 
+def remarks_with_sequence(remarks_data):
+    cmd = "remark"
+    if remarks_data.get("remarks"):
+        cmd += " " + remarks_data.get("remarks")
+    if remarks_data.get("sequence"):
+        cmd = to_text(remarks_data.get("sequence")) + " " + cmd
+    return cmd
+
+
 def _tmplt_access_list_entries(aces):
     def source_destination_common_config(config_data, command, attr):
         if config_data[attr].get("address"):
@@ -63,7 +73,9 @@ def _tmplt_access_list_entries(aces):
                 command += " {protocol_number}".format(**aces["protocol_options"])
             else:
                 command += " {0}".format(list(aces["protocol_options"])[0])
-                proto_option = aces["protocol_options"].get(list(aces["protocol_options"])[0])
+                proto_option = aces["protocol_options"].get(
+                    list(aces["protocol_options"])[0],
+                )
         elif aces.get("protocol"):
             command += " {protocol}".format(**aces)
         if aces.get("source"):
@@ -120,7 +132,7 @@ class AclsTemplate(NetworkTemplate):
 
     PARSERS = [
         {
-            "name": "acls_name",
+            "name": "only_acls_name",
             "getval": re.compile(
                 r"""^(?P<acl_type>Standard|Extended|Reflexive)*
                     \s*(?P<afi>IP|IPv6)*
@@ -130,8 +142,7 @@ class AclsTemplate(NetworkTemplate):
                     $""",
                 re.VERBOSE,
             ),
-            "compval": "name",
-            "setval": "name",
+            "setval": "",
             "result": {
                 "acls": {
                     "{{ acl_name|d() }}": {
@@ -141,56 +152,95 @@ class AclsTemplate(NetworkTemplate):
                     },
                 },
             },
-            "shared": True,
         },
         {
-            "name": "_acls_name",
+            "name": "acls_name",
             "getval": re.compile(
-                r"""^(ip|ipv6)
+                r"""^(?P<afi>ip|ipv6|mac)
                     (\s(access-list))
-                    (\s(standard|extended))
-                    (\s(?P<acl_name_r>\S+))?
+                    (\s(?P<acl_type>standard|extended|reflexive))?
+                    (\s(?P<acl_name>\S+))
                     $""",
                 re.VERBOSE,
             ),
-            "compval": "name",
-            "setval": "ip access-list",
-            "result": {},
+            "setval": "name",
+            "result": {
+                "acls": {
+                    "{{ acl_name|d() }}": {
+                        "name": "{{ acl_name }}",
+                        "acl_type": "{{ acl_type.lower() if acl_type is defined }}",
+                        "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
+                    },
+                },
+            },
             "shared": True,
         },
         {
             "name": "remarks",
             "getval": re.compile(
-                r"""\s+remark
-                    (\s(?P<remarks>.+))?
+                r"""((?P<order>^\d+))
+                    (\s*(?P<sequence>\d+))
+                    (\sremark\s(?P<remarks>.+))
                     $""",
                 re.VERBOSE,
             ),
-            "setval": "remark {{ remarks }}",
+            "setval": remarks_with_sequence,
             "result": {
                 "acls": {
-                    "{{ acl_name_r|d() }}": {
-                        "name": "{{ acl_name_r }}",
-                        "aces": [{"remarks": "{{ remarks }}"}],
+                    "{{ acl_name|d() }}": {
+                        "name": "{{ acl_name }}",
+                        "aces": [
+                            {
+                                "the_remark": "'{{ remarks }}'",
+                                "order": "{{ order }}",
+                                "is_remark_for": "{{ sequence }}",
+                            },
+                        ],
                     },
                 },
             },
         },
         {
-            "name": "remarks_type_linear",
+            "name": "remarks_no_data",
             "getval": re.compile(
-                r"""^(access-list)
-                    (\s(?P<acl_name_linear>\S+))?
-                    (\sremark\s(?P<remarks>.+))?
+                r"""(?P<order>^\d+)\s*remark\s(?P<remarks>.+)$""",
+                re.VERBOSE,
+            ),
+            "setval": remarks_with_sequence,
+            "result": {
+                "acls": {
+                    "{{ acl_name|d() }}": {
+                        "name": "{{ acl_name }}",
+                        "aces": [
+                            {
+                                "the_remark": "'{{ remarks }}'",
+                                "order": "{{ order }}",
+                                "is_remark_for": "remark",
+                            },
+                        ],
+                    },
+                },
+            },
+        },
+        {
+            "name": "remarks_ipv6",
+            "getval": re.compile(
+                r"""\s*(sequence\s(?P<sequence>\d+))
+                    (\sremark\s(?P<remarks>.+))
                     $""",
                 re.VERBOSE,
             ),
             "setval": "remark {{ remarks }}",
             "result": {
                 "acls": {
-                    "{{ acl_name_linear|d() }}": {
-                        "name": "{{ acl_name_linear }}",
-                        "aces": [{"remarks": "{{ remarks }}"}],
+                    "{{ acl_name|d() }}": {
+                        "name": "{{ acl_name }}",
+                        "aces": [
+                            {
+                                "sequence": "{{ sequence }}",
+                                "remarks": ["'{{ remarks }}'"],
+                            },
+                        ],
                     },
                 },
             },
@@ -198,12 +248,11 @@ class AclsTemplate(NetworkTemplate):
         {
             "name": "aces_ipv4_standard",
             "getval": re.compile(
-                r"""\s*(?P<sequence>\d+)*
-                        \s(?P<grant>deny|permit)?
-                        (\s+(?P<address>(?!ahp|eigrp|esp|gre|icmp|igmp|ipv6|ipinip|ip|nos|object-group|ospf|pcp|pim|sctp|tcp|udp)\S+|\S+,))?
+                r"""^\s*((?P<sequence>\d+))?
+                        (\s(?P<grant>deny|permit))
+                        (\s+(?P<address>((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)))?
+                        (\s(?P<wildcard>((25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)))?
                         (\s*(?P<any>any))?
-                        (\swildcard\sbits\s(?P<wildcard>\S+))?
-                        (\shost\s(?P<host>\S+))?
                         (\s(?P<log>log))?
                     $""",
                 re.VERBOSE,
@@ -221,7 +270,6 @@ class AclsTemplate(NetworkTemplate):
                                     "address": "{{ address }}",
                                     "wildcard_bits": "{{ wildcard }}",
                                     "any": "{{ not not any }}",
-                                    "host": "{{ host }}",
                                 },
                                 "log": {"set": "{{ not not log }}"},
                             },
@@ -233,22 +281,39 @@ class AclsTemplate(NetworkTemplate):
         {
             "name": "aces",
             "getval": re.compile(
-                r"""\s*(?P<sequence>\d+)*
-                        \s*(?P<grant>deny|permit)*
+                r"""^\s*((?P<sequence>\d+))?
+                        (\ssequence\s(?P<sequence_ipv6>\d+))?
+                        (\s(?P<grant>deny|permit))
                         (\sevaluate\s(?P<evaluate>\S+))?
-                        (\s(?P<protocol>ahp|eigrp|esp|gre|icmp|igmp|ipv6|ipinip|ip|nos|ospf|pcp|pim|sctp|tcp|udp))?
-                        (\s(?P<protocol_num>\d+))?
-                        (\s(?P<source>((object-group\s\S+\s|)(any|(\d{1,3}.\d{1,3}.\d{1,3}.\d{1,3})\s\S+|host\s\S+)))?)
-                        (\s(?P<source_port_protocol>(eq|gts|gt|lt|neq)\s(\S+|\d+)))?
+                        (\s(?P<protocol_num>\d+)\s)?
+                        (\s*(?P<protocol>ahp|eigrp|esp|gre|icmp|igmp|ipinip|ipv6|ip|nos|ospf|pcp|pim|sctp|tcp|ip|udp))?
+                        ((\s*(?P<source_any>any))|
+                        (\s*object-group\s(?P<source_obj_grp>\S+))|
+                        (\s*host\s(?P<source_host>\S+))|
+                        (\s*(?P<ipv6_source_address>\S+/\d+))|
+                        (\s*(?P<source_address>(\d{1,3}.\d{1,3}.\d{1,3}.\d{1,3})\s\S+)))?
+                        (\seq\s(?P<seq>(\S+|\d+)))?
+                        (\sgt\s(?P<sgt>(\S+|\d+)))?
+                        (\slt\s(?P<slt>(\S+|\d+)))?
+                        (\sneq\s(?P<sneq>(\S+|\d+)))?
                         (\srange\s(?P<srange_start>\d+)\s(?P<srange_end>\d+))?
-                        (\s(?P<destination>((object-group\s\S+\s|)(any|\d{1,3}.\d{1,3}.\d{1,3}.\d{1,3}\s\S+|host\s\S+)))?)
-                        (\s(?P<dest_port_protocol>(eq|gts|lt|neq)\s(\S+|\d+)))?
+                        (\s(?P<dest_any>any))?
+                        (\sobject-group\s(?P<dest_obj_grp>\S+))?
+                        (\shost\s(?P<dest_host>\S+))?
+                        (\s(?P<ipv6_dest_address>\S+/\d+))?
+                        (\s(?P<dest_address>(\d{1,3}.\d{1,3}.\d{1,3}.\d{1,3})\s\S+))?
+                        (\seq\s(?P<deq>(\S+|\d+)))?
+                        (\sgt\s(?P<dgt>(\S+|\d+)))?
+                        (\slt\s(?P<dlt>(\S+|\d+)))?
+                        (\sneq\s(?P<dneq>(\S+|\d+)))?
                         (\srange\s(?P<drange_start>\d+)\s(?P<drange_end>\d+))?
                         (\s(?P<icmp_igmp_tcp_protocol>administratively-prohibited|alternate-address|conversion-error|dod-host-prohibited|dod-net-prohibited|echo-reply|echo|general-parameter-problem|host-isolated|host-precedence-unreachable|host-redirect|host-tos-redirect|host-tos-unreachable|host-unknown|host-unreachable|information-reply|information-request|mask-reply|mask-request|mobile-redirect|net-redirect|net-tos-redirect|net-tos-unreachable|net-unreachable|network-unknown|no-room-for-option|option-missing|packet-too-big|parameter-problem|port-unreachable|precedence-unreachable|protocol-unreachable|reassembly-timeout|redirect|router-advertisement|router-solicitation|source-quench|source-route-failed|time-exceeded|timestamp-reply|timestamp-request|traceroute|ttl-exceeded|unreachable|dvmrp|host-query|mtrace-resp|mtrace-route|pim|trace|v1host-report|v2host-report|v2leave-group|v3host-report|ack|established|fin|psh|rst|syn|urg))?
                         (\sdscp\s(?P<dscp>\S+))?
                         (\s(?P<enable_fragments>fragments))?
-                        (\s(?P<log_input>log-input\s\(tag\s=\s\S+\)|log-input))?
-                        (\s(?P<log>log\s\(tag\s=\s\S+\)|log))?
+                        (\slog-input\s\(tag\s=\s(?P<log_input>\S+\)|log-input))?
+                        (\s(?P<log_input_only>log-input))?
+                        (\slog\s\(tag\s=\s(?P<log>\S+\)|log))?
+                        (\s(?P<log_only>log))?
                         (\soption\s(?P<option>\S+|\d+))?
                         (\sprecedence\s(?P<precedence>\S+))?
                         (\stime-range\s(?P<time_range>\S+))?
@@ -257,7 +322,6 @@ class AclsTemplate(NetworkTemplate):
                         (\sttl\sgt\s(?P<ttl_gt>\d+))?
                         (\sttl\slt\s(?P<ttl_lt>\d+))?
                         (\sttl\sneg\s(?P<ttl_neg>\d+))?
-                        (\ssequence\s(?P<sequence_ipv6>\d+))?
                     """,
                 re.VERBOSE,
             ),
@@ -277,11 +341,16 @@ class AclsTemplate(NetworkTemplate):
                                 "protocol_number": "{{ protocol_num }}",
                                 "icmp_igmp_tcp_protocol": "{{ icmp_igmp_tcp_protocol }}",
                                 "source": {
-                                    "remove": "{{ source }}",
-                                    "object_group": "{{ source.split(' ')[1] if source is defined and 'object-group' in source }}",
+                                    "address": "{{ source_address }}",
+                                    "ipv6_address": "{{ ipv6_source_address }}",
+                                    "any": "{{ not not source_any }}",
+                                    "host": "{{ source_host }}",
+                                    "object_group": "{{ source_obj_grp }}",
                                     "port_protocol": {
-                                        "{{ source_port_protocol.split(' ')[0] if source_port_protocol is defined else None }}": "{{\
-                                            source_port_protocol.split(' ')[1] if source_port_protocol is defined else None }}",
+                                        "eq": "{{ seq }}",
+                                        "gt": "{{ sgt }}",
+                                        "lt": "{{ slt }}",
+                                        "neq": "{{ sneq }}",
                                         "range": {
                                             "start": "{{ srange_start if srange_start is defined else None }}",
                                             "end": "{{ srange_end if srange_end is defined else None }}",
@@ -289,11 +358,16 @@ class AclsTemplate(NetworkTemplate):
                                     },
                                 },
                                 "destination": {
-                                    "remove": "{{ destination }}",
-                                    "object_group": "{{ destination.split(' ')[1] if destination is defined and 'object-group' in destination else None }}",
+                                    "address": "{{ dest_address }}",
+                                    "ipv6_address": "{{ ipv6_dest_address }}",
+                                    "any": "{{ not not dest_any }}",
+                                    "host": "{{ dest_host }}",
+                                    "object_group": "{{ dest_obj_grp }}",
                                     "port_protocol": {
-                                        "{{ dest_port_protocol.split(' ')[0] if dest_port_protocol is defined else None }}": "{{\
-                                            dest_port_protocol.split(' ')[1] if dest_port_protocol is defined else None }}",
+                                        "eq": "{{ deq }}",
+                                        "gt": "{{ dgt }}",
+                                        "lt": "{{ dlt }}",
+                                        "neq": "{{ dneq }}",
                                         "range": {
                                             "start": "{{ drange_start if drange_start is defined else None }}",
                                             "end": "{{ drange_end if drange_end is defined else None }}",
@@ -303,12 +377,12 @@ class AclsTemplate(NetworkTemplate):
                                 "dscp": "{{ dscp }}",
                                 "enable_fragments": "{{ True if enable_fragments is defined else None }}",
                                 "log": {
-                                    "set": "{{ True if log is defined and 'tag' not in log else '' }}",
-                                    "user_cookie": "{{ log.split(' ')[-1].split(')')[0] if log is defined and 'tag' in log else '' }}",
+                                    "set": "{{ True if log_only is defined or log is defined }}",
+                                    "user_cookie": "{{ log.split(')')[0] if log is defined }}",
                                 },
                                 "log_input": {
-                                    "set": "{{ True if log_input is defined and 'tag' not in log_input else '' }}",
-                                    "user_cookie": "{{ log_input.split(' ')[-1].split(')')[0] if log_input is defined and 'tag' in log_input }}",
+                                    "set": "{{ True if log_input_only is defined or log_input is defined }}",
+                                    "user_cookie": "{{ log_input.split(')')[0] if log_input is defined }}",
                                 },
                                 "option": {
                                     "{{ option if option is defined else None }}": "{{ True if option is defined else None }}",
