@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2021, Cisco Systems
+# Copyright (c) 2024, Cisco Systems
 # GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 from __future__ import absolute_import, division, print_function
@@ -229,7 +229,15 @@ class ActionModule(ActionBase):
                     self._result.update(dict(ise_update_response=ise_update_response))
                     (obj_exists, updated_obj) = obj.exists()
                     response = updated_obj
-                    ise.object_updated()
+                    has_changed = None
+                    has_changed = ise_update_response.get("UpdatedFieldsList").get("updatedField")
+                    if (len(has_changed) == 0 or
+                       has_changed[0].get("newValue") == "" and
+                       has_changed[0].get("newValue") == has_changed[0].get("oldValue")):
+                        self._result.pop("ise_update_response", None)
+                        ise.object_already_present()
+                    else:
+                        ise.object_updated()
                 else:
                     response = prev_obj
                     ise.object_already_present()
