@@ -52,6 +52,9 @@ options:
       condition:
         description: Device Administration Authorization Rules's condition.
         suboptions:
+          attributeId:
+            description: Dictionary attribute id (Optional), used for additional verification.
+            type: str
           attributeName:
             description: Dictionary attribute name.
             type: str
@@ -98,11 +101,12 @@ options:
               that additional conditions are present under the children field</li></ul>.
             type: str
           datesRange:
-            description: <p>Defines for which date/s TimeAndDate condition will be matched<br>
-              Options are - Date range, for specific date, the same date should be used
-              for start/end date <br> Default - no specific dates<br> In order to reset
-              the dates to have no specific dates Date format - yyyy-mm-dd (MM = month,
-              dd = day, yyyy = year)</p>.
+            description: <p>Defines for which date/s TimeAndDate condition will be matched
+              or NOT matched if used in exceptionDates prooperty<br> Options are - Date
+              range, for specific date, the same date should be used for start/end date
+              <br> Default - no specific dates<br> In order to reset the dates to have
+              no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy
+              = year)</p>.
             suboptions:
               endDate:
                 description: Device Administration Authorization Rules's endDate.
@@ -112,11 +116,12 @@ options:
                 type: str
             type: dict
           datesRangeException:
-            description: <p>Defines for which date/s TimeAndDate condition will be matched<br>
-              Options are - Date range, for specific date, the same date should be used
-              for start/end date <br> Default - no specific dates<br> In order to reset
-              the dates to have no specific dates Date format - yyyy-mm-dd (MM = month,
-              dd = day, yyyy = year)</p>.
+            description: <p>Defines for which date/s TimeAndDate condition will be matched
+              or NOT matched if used in exceptionDates prooperty<br> Options are - Date
+              range, for specific date, the same date should be used for start/end date
+              <br> Default - no specific dates<br> In order to reset the dates to have
+              no specific dates Date format - yyyy-mm-dd (MM = month, dd = day, yyyy
+              = year)</p>.
             suboptions:
               endDate:
                 description: Device Administration Authorization Rules's endDate.
@@ -136,8 +141,8 @@ options:
             type: str
           hoursRange:
             description: <p>Defines for which hours a TimeAndDate condition will be
-              matched<br> Time format - hh mm ( h = hour , mm = minutes ) <br> Default
-              - All Day </p>.
+              matched or not matched if used in exceptionHours property<br> Time foramt
+              - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
             suboptions:
               endTime:
                 description: Device Administration Authorization Rules's endTime.
@@ -148,8 +153,8 @@ options:
             type: dict
           hoursRangeException:
             description: <p>Defines for which hours a TimeAndDate condition will be
-              matched<br> Time format - hh mm ( h = hour , mm = minutes ) <br> Default
-              - All Day </p>.
+              matched or not matched if used in exceptionHours property<br> Time foramt
+              - hh mm ( h = hour , mm = minutes ) <br> Default - All Day </p>.
             suboptions:
               endTime:
                 description: Device Administration Authorization Rules's endTime.
@@ -217,7 +222,7 @@ options:
         type: str
     type: dict
 requirements:
-- ciscoisesdk >= 2.0.3
+- ciscoisesdk >= 2.2.3
 - python >= 3.5
 seealso:
 - name: Cisco ISE documentation for Device Administration - Authorization Rules
@@ -254,6 +259,7 @@ EXAMPLES = r"""
     profile: string
     rule:
       condition:
+        attributeId: string
         attributeName: string
         attributeValue: string
         children:
@@ -316,6 +322,7 @@ EXAMPLES = r"""
     profile: string
     rule:
       condition:
+        attributeId: string
         attributeName: string
         attributeValue: string
         children:
@@ -401,6 +408,7 @@ ise_response:
           "id": "string",
           "name": "string",
           "attributeName": "string",
+          "attributeId": "string",
           "attributeValue": "string",
           "dictionaryName": "string",
           "dictionaryValue": "string",
@@ -478,6 +486,7 @@ ise_update_response:
             "id": "string",
             "name": "string",
             "attributeName": "string",
+            "attributeId": "string",
             "attributeValue": "string",
             "dictionaryName": "string",
             "dictionaryValue": "string",
