@@ -12,7 +12,7 @@ from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
 
-DOCUMENTATION = '''
+DOCUMENTATION = r'''
 name: docker_containers
 short_description: Ansible dynamic inventory plugin for Docker containers
 version_added: 1.1.0
@@ -21,9 +21,15 @@ author:
 extends_documentation_fragment:
     - ansible.builtin.constructed
     - community.docker.docker.api_documentation
+    - community.docker.docker.ssl_version_deprecation
+    - community.library_inventory_filtering_v1.inventory_filter
 description:
     - Reads inventories from the Docker API.
-    - Uses a YAML configuration file that ends with C(docker.[yml|yaml]).
+    - Uses a YAML configuration file that ends with V(docker.(yml|yaml\)).
+notes:
+    - The configuration file must be a YAML file whose filename ends with V(docker.yml) or V(docker.yaml).
+      Other filenames will not be accepted.
+
 options:
     plugin:
         description:
@@ -101,12 +107,15 @@ options:
               See the examples for how to do that.
         type: bool
         default: false
+
+    filters:
+        version_added: 3.5.0
 '''
 
 EXAMPLES = '''
 # Minimal example using local Docker daemon
 plugin: community.docker.docker_containers
-docker_host: unix://var/run/docker.sock
+docker_host: unix:///var/run/docker.sock
 
 # Minimal example using remote Docker daemon
 plugin: community.docker.docker_containers
@@ -121,7 +130,7 @@ tls: true
 plugin: community.docker.docker_containers
 docker_host: tcp://my-docker-host:2376
 validate_certs: true
-ca_cert: /somewhere/ca.pem
+ca_path: /somewhere/ca.pem
 client_key: /somewhere/key.pem
 client_cert: /somewhere/cert.pem
 
@@ -144,6 +153,18 @@ connection_type: ssh
 compose:
   ansible_ssh_host: ansible_ssh_host | default(docker_name[1:], true)
   ansible_ssh_port: ansible_ssh_port | default(22, true)
+
+# Only consider containers which have a label 'foo', or whose name starts with 'a'
+plugin: community.docker.docker_containers
+filters:
+  # Accept all containers which have a label called 'foo'
+  - include: >-
+      "foo" in docker_config.Labels
+  # Next accept all containers whose inventory_hostname starts with 'a'
+  - include: >-
+      inventory_hostname.startswith("a")
+  # Exclude all containers that didn't match any of the above filters
+  - exclude: true
 '''
 
 import re
@@ -163,6 +184,8 @@ from ansible_collections.community.docker.plugins.plugin_utils.common_api import
 )
 
 from ansible_collections.community.docker.plugins.module_utils._api.errors import APIError, DockerException
+from ansible_collections.community.docker.plugins.plugin_utils.unsafe import make_unsafe
+from ansible_collections.community.library_inventory_filtering_v1.plugins.plugin_utils.inventory_filter import parse_filters, filter_host
 
 MIN_DOCKER_API = None
 
@@ -209,6 +232,7 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
                 if value is not None:
                     extra_facts[var_name] = value
 
+        filters = parse_filters(self.get_option('filters'))
         for container in containers:
             id = container.get('Id')
             short_id = id[:13]
@@ -220,10 +244,9 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
                 name = short_id
                 full_name = id
 
-            self.inventory.add_host(name)
             facts = dict(
-                docker_name=name,
-                docker_short_id=short_id
+                docker_name=make_unsafe(name),
+                docker_short_id=make_unsafe(short_id),
             )
             full_facts = dict()
 
@@ -238,26 +261,26 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
 
             running = state.get('Running')
 
+            groups = []
+
             # Add container to groups
             image_name = config.get('Image')
             if image_name and add_legacy_groups:
-                self.inventory.add_group('image_{0}'.format(image_name))
-                self.inventory.add_host(name, group='image_{0}'.format(image_name))
+                groups.append('image_{0}'.format(image_name))
 
             stack_name = labels.get('com.docker.stack.namespace')
             if stack_name:
                 full_facts['docker_stack'] = stack_name
                 if add_legacy_groups:
-                    self.inventory.add_group('stack_{0}'.format(stack_name))
-                    self.inventory.add_host(name, group='stack_{0}'.format(stack_name))
+                    groups.append('stack_{0}'.format(stack_name))
 
             service_name = labels.get('com.docker.swarm.service.name')
             if service_name:
                 full_facts['docker_service'] = service_name
                 if add_legacy_groups:
-                    self.inventory.add_group('service_{0}'.format(service_name))
-                    self.inventory.add_host(name, group='service_{0}'.format(service_name))
+                    groups.append('service_{0}'.format(service_name))
 
+            ansible_connection = None
             if connection_type == 'ssh':
                 # Figure out ssh IP and Port
                 try:
@@ -280,23 +303,38 @@ class InventoryModule(BaseInventoryPlugin, Constructable):
             elif connection_type == 'docker-cli':
                 facts.update(dict(
                     ansible_host=full_name,
-                    ansible_connection='community.docker.docker',
                 ))
+                ansible_connection = 'community.docker.docker'
             elif connection_type == 'docker-api':
                 facts.update(dict(
                     ansible_host=full_name,
-                    ansible_connection='community.docker.docker_api',
                 ))
                 facts.update(extra_facts)
+                ansible_connection = 'community.docker.docker_api'
 
             full_facts.update(facts)
             for key, value in inspect.items():
                 fact_key = self._slugify(key)
                 full_facts[fact_key] = value
 
+            full_facts = make_unsafe(full_facts)
+
+            if ansible_connection:
+                for d in (facts, full_facts):
+                    if 'ansible_connection' not in d:
+                        d['ansible_connection'] = ansible_connection
+
+            if not filter_host(self, name, full_facts, filters):
+                continue
+
             if verbose_output:
                 facts.update(full_facts)
 
+            self.inventory.add_host(name)
+            for group in groups:
+                self.inventory.add_group(group)
+                self.inventory.add_host(name, group=group)
+
             for key, value in facts.items():
                 self.inventory.set_variable(name, key, value)
 
