@@ -275,11 +275,10 @@ class InventoryModule(BaseInventoryPlugin, Constructable, Cacheable):
         return self.session
 
     def _get_auth(self):
-        credentials = urlencode({'username': self.proxmox_user, 'password': self.proxmox_password, })
 
         if self.proxmox_password:
 
-            credentials = urlencode({'username': self.proxmox_user, 'password': self.proxmox_password, })
+            credentials = urlencode({'username': self.proxmox_user, 'password': self.proxmox_password})
 
             a = self._get_session()
 
