@@ -171,6 +171,14 @@ context:
   returned: success
   type: str
   sample: user
+queries:
+  description:
+  - List of executed DML queries.
+  returned: success
+  type: list
+  elements: str
+  sample: ["ALTER SYSTEM SET shared_preload_libraries = ''"]
+  version_added: '3.7.0'
 '''
 
 from copy import deepcopy
@@ -188,6 +196,8 @@ from ansible_collections.community.postgresql.plugins.module_utils.postgres impo
     postgres_common_argument_spec,
 )
 
+executed_queries = []
+
 PG_REQ_VER = 90400
 
 # To allow to set value like 1mb instead of 1MB, etc:
@@ -375,6 +385,8 @@ def param_set(cursor, module, name, value, context, server_version):
                 query = "ALTER SYSTEM SET %s = %s" % (name, value)
             else:
                 query = "ALTER SYSTEM SET %s = '%s'" % (name, value)
+
+        executed_queries.append(query)
         cursor.execute(query)
 
         if context != 'postmaster':
@@ -386,6 +398,19 @@ def param_set(cursor, module, name, value, context, server_version):
     return True
 
 
+def param_reset(cursor, module, name, context):
+    try:
+        query = "ALTER SYSTEM RESET %s" % name
+        cursor.execute(query)
+
+        if context != 'postmaster':
+            cursor.execute("SELECT pg_reload_conf()")
+
+    except Exception as e:
+        module.fail_json(msg="Unable to reset %s due to : %s" % (name, to_native(e)))
+
+    return True
+
 # ===========================================
 # Module execution.
 #
@@ -425,6 +450,14 @@ def main():
         elif len(value) > 1 and ('b' in value[-1] and value[:-1].isdigit()):
             value = value.upper()
 
+    if name == 'shared_preload_libraries' and value == '':
+        msg = ("Due to a PostgreSQL bug in resetting shared_preload_libraries "
+               "with ALTER SYSTEM SET, setting it as an empty string "
+               "is not supported by the module to avoid crashes. "
+               "Use the `value: default` or `reset: true` argument instead. "
+               "If you think the bug has been fixed, please let us know.")
+        module.fail_json(msg=msg)
+
     if value is not None and reset:
         module.fail_json(msg="%s: value and reset params are mutually exclusive" % name)
 
@@ -502,6 +535,7 @@ def main():
             unit=unit,
         )
         kw['restart_required'] = restart_required
+        kw['queries'] = executed_queries
         module.exit_json(**kw)
 
     # Set param (value can be an empty string):
@@ -518,9 +552,10 @@ def main():
                 value=raw_val,
                 unit=unit,
             )
+            kw['queries'] = executed_queries
             module.exit_json(**kw)
 
-        changed = param_set(cursor, module, name, boot_val, context, ver)
+        changed = param_reset(cursor, module, name, context)
 
     cursor.close()
     db_connection.close()
@@ -552,6 +587,7 @@ def main():
 
     kw['changed'] = changed
     kw['restart_required'] = restart_required
+    kw['queries'] = executed_queries
 
     if restart_required and changed:
         module.warn("Restart of PostgreSQL is required for setting %s" % name)
