@@ -3,8 +3,8 @@
 
 #
 # Dell OpenManage Ansible Modules
-# Version 7.0.0
-# Copyright (C) 2020-2022 Dell Inc. or its subsidiaries. All Rights Reserved.
+# Version 9.3.0
+# Copyright (C) 2020-2024 Dell Inc. or its subsidiaries. All Rights Reserved.
 
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 #
@@ -37,7 +37,7 @@ options:
         type: str
 
 requirements:
-    - "python >= 3.8.6"
+    - "python >= 3.9.6"
 author: "Deepak Joshi(@deepakjoshishri)"
 notes:
     - Run this module from a system that has direct access to Dell OpenManage Enterprise.
@@ -151,8 +151,7 @@ error_info:
 
 import json
 from ssl import SSLError
-from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.dellemc.openmanage.plugins.module_utils.ome import RestOME, ome_auth_params
+from ansible_collections.dellemc.openmanage.plugins.module_utils.ome import RestOME, OmeAnsibleModule
 from ansible.module_utils.six.moves.urllib.error import URLError, HTTPError
 from ansible.module_utils.urls import ConnectionError, SSLValidationError
 
@@ -216,8 +215,8 @@ def main():
         "id": {"required": False, "type": 'int'},
         "name": {"required": False, "type": 'str'}
     }
-    specs.update(ome_auth_params)
-    module = AnsibleModule(
+
+    module = OmeAnsibleModule(
         argument_spec=specs,
         mutually_exclusive=[["id", "name"]],
         supports_check_mode=True)
