@@ -87,7 +87,7 @@ options:
             archive-block:
                 type: list
                 elements: str
-                description: Deprecated, please rename it to archive_block.
+                description: Deprecated, please rename it to archive_block. Select the archive types to block.
                 choices:
                     - 'encrypted'
                     - 'corrupted'
@@ -101,7 +101,7 @@ options:
             archive-log:
                 type: list
                 elements: str
-                description: Deprecated, please rename it to archive_log.
+                description: Deprecated, please rename it to archive_log. Select the archive types to log.
                 choices:
                     - 'encrypted'
                     - 'corrupted'
@@ -133,7 +133,7 @@ options:
             options:
                 type: list
                 elements: str
-                description: No description.
+                description: Enable/disable SMTP AntiVirus scanning, monitoring, and quarantine.
                 choices:
                     - 'scan'
                     - 'file-filter'
@@ -348,14 +348,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'antivirus_profile_smtp'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_partial_curd(argument_specs=module_arg_spec)
