@@ -308,7 +308,7 @@ options:
             default-network-services:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to default_network_services. Default-Network-Services.
+                description: Deprecated, please rename it to default_network_services. Default network services.
                 suboptions:
                     id:
                         type: int
@@ -517,7 +517,7 @@ def main():
                         'sub-category': {'type': 'raw'},
                         'technology': {'type': 'raw'},
                         'vendor': {'type': 'raw'},
-                        'tags': {'v_range': [['6.2.0', '6.4.13']], 'type': 'str'},
+                        'tags': {'v_range': [['6.2.0', '6.4.14']], 'type': 'str'},
                         'exclusion': {'v_range': [['6.2.7', '6.2.12'], ['6.4.3', '']], 'type': 'raw'}
                     },
                     'elements': 'dict'
@@ -561,14 +561,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'application_list'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
