@@ -107,7 +107,7 @@ options:
             control-options:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to control_options.
+                description: Deprecated, please rename it to control_options. Control options.
                 suboptions:
                     name:
                         type: str
@@ -115,7 +115,7 @@ options:
                     operations:
                         type: list
                         elements: dict
-                        description: No description.
+                        description: Operations.
                         suboptions:
                             action:
                                 type: str
@@ -169,7 +169,7 @@ options:
                             values:
                                 type: list
                                 elements: str
-                                description: No description.
+                                description: CASB operation new values.
                     status:
                         type: str
                         description: CASB control option status.
@@ -182,7 +182,7 @@ options:
             match:
                 type: list
                 elements: dict
-                description: No description.
+                description: Match.
                 suboptions:
                     id:
                         type: int
@@ -190,7 +190,7 @@ options:
                     rules:
                         type: list
                         elements: dict
-                        description: No description.
+                        description: Rules.
                         suboptions:
                             case-sensitive:
                                 type: str
@@ -201,7 +201,7 @@ options:
                             domains:
                                 type: list
                                 elements: str
-                                description: No description.
+                                description: CASB user activity domain list.
                             header-name:
                                 type: str
                                 description: Deprecated, please rename it to header_name. CASB user activity rule header name.
@@ -221,7 +221,7 @@ options:
                             methods:
                                 type: list
                                 elements: str
-                                description: No description.
+                                description: CASB user activity method list.
                             negate:
                                 type: str
                                 description: Enable/disable what the matching strategy must not be.
@@ -480,14 +480,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'casb_useractivity'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
