@@ -193,11 +193,11 @@ def main():
         'devprof': {'required': True, 'type': 'str'},
         'devprof_log_syslogd_setting_customfieldname': {
             'type': 'dict',
-            'v_range': [['7.0.4', '7.0.10'], ['7.2.1', '']],
+            'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']],
             'options': {
-                'custom': {'v_range': [['7.0.4', '7.0.10'], ['7.2.1', '']], 'type': 'str'},
-                'id': {'v_range': [['7.0.4', '7.0.10'], ['7.2.1', '']], 'required': True, 'type': 'int'},
-                'name': {'v_range': [['7.0.4', '7.0.10'], ['7.2.1', '']], 'type': 'str'}
+                'custom': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'type': 'str'},
+                'id': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'required': True, 'type': 'int'},
+                'name': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'type': 'str'}
             }
 
         }
@@ -208,14 +208,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'devprof_log_syslogd_setting_customfieldname'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
