@@ -98,7 +98,7 @@ options:
             action:
                 type: list
                 elements: str
-                description: No description.
+                description: Action to take on this end point
                 choices:
                     - 'block'
                     - 'exempt'
@@ -110,7 +110,7 @@ options:
             log-action:
                 type: list
                 elements: str
-                description: Deprecated, please rename it to log_action.
+                description: Deprecated, please rename it to log_action. Action to take on this end point
                 choices:
                     - 'archive'
                     - 'intercept'
@@ -258,14 +258,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'firewall_carrierendpointbwl_entries'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
