@@ -228,21 +228,21 @@ def main():
         'adom': {'required': True, 'type': 'str'},
         'log_npuserver_servergroup': {
             'type': 'dict',
-            'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+            'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']],
             'options': {
-                'group-name': {'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']], 'type': 'str'},
-                'log-format': {'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']], 'choices': ['syslog', 'netflow'], 'type': 'str'},
+                'group-name': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'type': 'str'},
+                'log-format': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'choices': ['syslog', 'netflow'], 'type': 'str'},
                 'log-mode': {
-                    'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']],
+                    'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']],
                     'choices': ['per-session', 'per-nat-mapping', 'per-session-ending'],
                     'type': 'str'
                 },
-                'log-tx-mode': {'v_range': [['6.4.7', '6.4.13'], ['7.0.2', '']], 'choices': ['multicast', 'roundrobin'], 'type': 'str'},
-                'server-number': {'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']], 'type': 'int'},
-                'server-start-id': {'v_range': [['6.4.7', '6.4.13'], ['7.0.1', '']], 'type': 'int'},
-                'sw-log-flags': {'v_range': [['6.4.8', '6.4.13'], ['7.0.3', '']], 'type': 'raw'},
-                'log-gen-event': {'v_range': [['7.0.4', '7.0.10'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'log-user-info': {'v_range': [['7.0.4', '7.0.10'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
+                'log-tx-mode': {'v_range': [['6.4.7', '6.4.14'], ['7.0.2', '']], 'choices': ['multicast', 'roundrobin'], 'type': 'str'},
+                'server-number': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'type': 'int'},
+                'server-start-id': {'v_range': [['6.4.7', '6.4.14'], ['7.0.1', '']], 'type': 'int'},
+                'sw-log-flags': {'v_range': [['6.4.8', '6.4.14'], ['7.0.3', '']], 'type': 'raw'},
+                'log-gen-event': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
+                'log-user-info': {'v_range': [['7.0.4', '7.0.12'], ['7.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'}
             }
 
         }
@@ -253,14 +253,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'log_npuserver_servergroup'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
