@@ -367,16 +367,16 @@ options:
                     - 'enable'
             internet-service6-custom:
                 type: raw
-                description: (list) Deprecated, please rename it to internet_service6_custom.
+                description: (list) Deprecated, please rename it to internet_service6_custom. Custom IPv6 Internet Service name.
             internet-service6-custom-group:
                 type: raw
-                description: (list) Deprecated, please rename it to internet_service6_custom_group.
+                description: (list) Deprecated, please rename it to internet_service6_custom_group. Custom IPv6 Internet Service group name.
             internet-service6-group:
                 type: raw
-                description: (list) Deprecated, please rename it to internet_service6_group.
+                description: (list) Deprecated, please rename it to internet_service6_group. Internet Service group name.
             internet-service6-name:
                 type: raw
-                description: (list) Deprecated, please rename it to internet_service6_name.
+                description: (list) Deprecated, please rename it to internet_service6_name. IPv6 Internet Service name.
             internet-service6-negate:
                 type: str
                 description: Deprecated, please rename it to internet_service6_negate. When enabled internet-service6 specifies what the service must N...
@@ -391,16 +391,16 @@ options:
                     - 'enable'
             internet-service6-src-custom:
                 type: raw
-                description: (list) Deprecated, please rename it to internet_service6_src_custom.
+                description: (list) Deprecated, please rename it to internet_service6_src_custom. Custom IPv6 Internet Service source name.
             internet-service6-src-custom-group:
                 type: raw
-                description: (list) Deprecated, please rename it to internet_service6_src_custom_group.
+                description: (list) Deprecated, please rename it to internet_service6_src_custom_group. Custom Internet Service6 source group name.
             internet-service6-src-group:
                 type: raw
-                description: (list) Deprecated, please rename it to internet_service6_src_group.
+                description: (list) Deprecated, please rename it to internet_service6_src_group. Internet Service6 source group name.
             internet-service6-src-name:
                 type: raw
-                description: (list) Deprecated, please rename it to internet_service6_src_name.
+                description: (list) Deprecated, please rename it to internet_service6_src_name. IPv6 Internet Service source name.
             internet-service6-src-negate:
                 type: str
                 description: Deprecated, please rename it to internet_service6_src_negate. When enabled internet-service6-src specifies what the servic...
@@ -640,7 +640,7 @@ def main():
                 'ips-sensor': {'v_range': [['6.2.1', '']], 'type': 'str'},
                 'logtraffic': {'v_range': [['6.2.1', '']], 'choices': ['disable', 'all', 'utm'], 'type': 'str'},
                 'logtraffic-start': {'v_range': [['6.2.1', '']], 'choices': ['disable', 'enable'], 'type': 'str'},
-                'mms-profile': {'v_range': [['6.2.1', '7.2.0']], 'type': 'str'},
+                'mms-profile': {'v_range': [['6.2.1', '7.2.0'], ['7.4.3', '']], 'type': 'str'},
                 'name': {'v_range': [['6.2.1', '']], 'type': 'str'},
                 'policyid': {'v_range': [['6.2.1', '']], 'required': True, 'type': 'int'},
                 'profile-group': {'v_range': [['6.2.1', '']], 'type': 'str'},
@@ -718,14 +718,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'pkg_firewall_securitypolicy'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
