@@ -120,7 +120,7 @@ options:
             custom-tlvs:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to custom_tlvs. Custom-Tlvs.
+                description: Deprecated, please rename it to custom_tlvs. Custom tlvs.
                 suboptions:
                     information-string:
                         type: str
@@ -137,7 +137,7 @@ options:
             med-network-policy:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to med_network_policy. Med-Network-Policy.
+                description: Deprecated, please rename it to med_network_policy. Med network policy.
                 suboptions:
                     dscp:
                         type: int
@@ -182,7 +182,7 @@ options:
             med-location-service:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to med_location_service. Med-Location-Service.
+                description: Deprecated, please rename it to med_location_service. Med location service.
                 suboptions:
                     name:
                         type: str
@@ -416,14 +416,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'switchcontroller_lldpprofile'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
