@@ -12,7 +12,7 @@ ANSIBLE_METADATA = {'status': ['preview'],
 DOCUMENTATION = '''
 ---
 module: fmgr_sys_cloud_orchest
-short_description: no description
+short_description: Sys cloud orchest
 description:
     - This module is able to configure a FortiManager device.
     - Examples include all parameters and values which need to be adjusted to data sources before usage.
@@ -71,20 +71,20 @@ options:
         suboptions:
             action:
                 type: str
-                description: No description.
+                description: Action.
                 choices:
                     - 'deploy'
                     - 'undeploy'
                     - 'status'
             adom:
                 type: str
-                description: No description.
+                description: Adom.
             adom_oid:
                 type: int
-                description: No description.
+                description: Adom oid.
             name:
                 type: str
-                description: No description.
+                description: Name.
 '''
 
 EXAMPLES = '''
@@ -96,7 +96,7 @@ EXAMPLES = '''
     ansible_httpapi_validate_certs: false
     ansible_httpapi_port: 443
   tasks:
-    - name: No description
+    - name: Sys cloud orchest
       fortinet.fortimanager.fmgr_sys_cloud_orchest:
         # bypass_validation: false
         workspace_locking_adom: <value in [global, custom adom including root]>
@@ -187,14 +187,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'sys_cloud_orchest'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_exec(argument_specs=module_arg_spec)
