@@ -143,7 +143,7 @@ options:
                         description: Deprecated, please rename it to msg_type. Message type.
                     id:
                         type: int
-                        description: No description.
+                        description: Id.
             auth:
                 type: list
                 elements: dict
@@ -176,7 +176,7 @@ options:
             custom-message:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to custom_message. Custom-Message.
+                description: Deprecated, please rename it to custom_message. Custom message.
                 suboptions:
                     buffer:
                         type: str
@@ -202,7 +202,7 @@ options:
             device-detection-portal:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to device_detection_portal. Device-Detection-Portal.
+                description: Deprecated, please rename it to device_detection_portal. Device detection portal.
                 suboptions:
                     buffer:
                         type: str
@@ -228,7 +228,7 @@ options:
             ec:
                 type: list
                 elements: dict
-                description: No description.
+                description: Ec.
                 suboptions:
                     buffer:
                         type: str
@@ -254,7 +254,7 @@ options:
             fortiguard-wf:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to fortiguard_wf. Fortiguard-Wf.
+                description: Deprecated, please rename it to fortiguard_wf. Fortiguard wf.
                 suboptions:
                     buffer:
                         type: str
@@ -443,9 +443,9 @@ options:
                     image:
                         type: str
                         description: Message string.
-                    message:
+                    fmgr_message:
                         type: str
-                        description: Deprecated, please rename it to fmgr_message. Message text
+                        description: Message text
                     msg-type:
                         type: str
                         description: Deprecated, please rename it to msg_type. Message type.
@@ -533,9 +533,9 @@ options:
                     image:
                         type: str
                         description: Message string.
-                    message:
+                    fmgr_message:
                         type: str
-                        description: Deprecated, please rename it to fmgr_message. Message text
+                        description: Message text
                     msg-type:
                         type: str
                         description: Deprecated, please rename it to msg_type. Message type.
@@ -606,9 +606,9 @@ options:
                     image:
                         type: str
                         description: Message string.
-                    message:
+                    fmgr_message:
                         type: str
-                        description: Deprecated, please rename it to fmgr_message. Message text
+                        description: Message text
                     msg-type:
                         type: str
                         description: Deprecated, please rename it to msg_type. Message type.
@@ -704,9 +704,9 @@ options:
                     image:
                         type: str
                         description: Message string.
-                    message:
+                    fmgr_message:
                         type: str
-                        description: Deprecated, please rename it to fmgr_message. Message text
+                        description: Message text
                     msg-type:
                         type: str
                         description: Deprecated, please rename it to msg_type. Message type.
@@ -792,7 +792,7 @@ options:
             nac-quar:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to nac_quar. Nac-Quar.
+                description: Deprecated, please rename it to nac_quar. Nac quar.
                 suboptions:
                     buffer:
                         type: str
@@ -817,7 +817,7 @@ options:
                         description: Deprecated, please rename it to msg_type. Message type.
                     id:
                         type: int
-                        description: No description.
+                        description: Id.
             name:
                 type: str
                 description: Group name.
@@ -903,7 +903,7 @@ options:
             traffic-quota:
                 type: list
                 elements: dict
-                description: Deprecated, please rename it to traffic_quota. Traffic-Quota.
+                description: Deprecated, please rename it to traffic_quota. Traffic quota.
                 suboptions:
                     buffer:
                         type: str
@@ -1124,7 +1124,7 @@ def main():
                         'format': {'choices': ['none', 'text', 'html', 'wml'], 'type': 'str'},
                         'header': {'choices': ['none', 'http', '8bit'], 'type': 'str'},
                         'msg-type': {'type': 'str'},
-                        'id': {'v_range': [['6.4.11', '6.4.13'], ['7.0.6', '7.0.10'], ['7.2.3', '']], 'type': 'int'}
+                        'id': {'v_range': [['6.4.11', '6.4.14'], ['7.0.6', '7.0.12'], ['7.2.3', '']], 'type': 'int'}
                     },
                     'elements': 'dict'
                 },
@@ -1232,7 +1232,7 @@ def main():
                         'from-sender': {'choices': ['disable', 'enable'], 'type': 'str'},
                         'header': {'choices': ['none', 'http', '8bit'], 'type': 'str'},
                         'image': {'type': 'str'},
-                        'message': {'type': 'str'},
+                        'fmgr_message': {'type': 'str'},
                         'msg-type': {'type': 'str'},
                         'priority': {'choices': ['low', 'normal', 'high', 'not-included'], 'type': 'str'},
                         'rsp-status': {
@@ -1260,7 +1260,7 @@ def main():
                         'header': {'choices': ['none', 'http', '8bit'], 'type': 'str'},
                         'html-part': {'type': 'str'},
                         'image': {'type': 'str'},
-                        'message': {'type': 'str'},
+                        'fmgr_message': {'type': 'str'},
                         'msg-type': {'type': 'str'},
                         'priority': {'choices': ['low', 'normal', 'high', 'not-included'], 'type': 'str'},
                         'subject': {'type': 'str'}
@@ -1279,7 +1279,7 @@ def main():
                         'from-sender': {'choices': ['disable', 'enable'], 'type': 'str'},
                         'header': {'choices': ['none', 'http', '8bit'], 'type': 'str'},
                         'image': {'type': 'str'},
-                        'message': {'type': 'str'},
+                        'fmgr_message': {'type': 'str'},
                         'msg-type': {'type': 'str'},
                         'priority': {'choices': ['low', 'normal', 'high', 'not-included'], 'type': 'str'},
                         'rsp-status': {
@@ -1307,7 +1307,7 @@ def main():
                         'from-sender': {'choices': ['disable', 'enable'], 'type': 'str'},
                         'header': {'choices': ['none', 'http', '8bit'], 'type': 'str'},
                         'image': {'type': 'str'},
-                        'message': {'type': 'str'},
+                        'fmgr_message': {'type': 'str'},
                         'msg-type': {'type': 'str'},
                         'priority': {'choices': ['low', 'normal', 'high', 'not-included'], 'type': 'str'},
                         'rsp-status': {
@@ -1343,7 +1343,7 @@ def main():
                         'format': {'choices': ['none', 'text', 'html', 'wml'], 'type': 'str'},
                         'header': {'choices': ['none', 'http', '8bit'], 'type': 'str'},
                         'msg-type': {'type': 'str'},
-                        'id': {'v_range': [['6.4.11', '6.4.13'], ['7.0.6', '7.0.10'], ['7.2.3', '']], 'type': 'int'}
+                        'id': {'v_range': [['6.4.11', '6.4.14'], ['7.0.6', '7.0.12'], ['7.2.3', '']], 'type': 'int'}
                     },
                     'elements': 'dict'
                 },
@@ -1429,14 +1429,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'system_replacemsggroup'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
