@@ -95,7 +95,7 @@ options:
         suboptions:
             _dynamic-member:
                 type: str
-                description: Deprecated, please rename it to _dynamic_member.
+                description: Deprecated, please rename it to _dynamic_member. Dynamic member.
             comment:
                 type: str
                 description: Comments.
@@ -120,6 +120,7 @@ options:
             seq-num:
                 type: int
                 description: Deprecated, please rename it to seq_num. Sequence number
+                required: true
             source:
                 type: str
                 description: Source IP address used in the health-check packet to the server.
@@ -153,6 +154,12 @@ options:
             transport-group:
                 type: int
                 description: Deprecated, please rename it to transport_group. Measured transport group
+            priority-in-sla:
+                type: int
+                description: Deprecated, please rename it to priority_in_sla. Preferred priority of routes to this member when this member is in-sla
+            priority-out-sla:
+                type: int
+                description: Deprecated, please rename it to priority_out_sla. Preferred priority of routes to this member when this member is out-of-sla
 '''
 
 EXAMPLES = '''
@@ -194,6 +201,8 @@ EXAMPLES = '''
           priority6: <integer>
           preferred_source: <string>
           transport_group: <integer>
+          priority_in_sla: <integer>
+          priority_out_sla: <integer>
 '''
 
 RETURN = '''
@@ -253,7 +262,7 @@ def main():
     ]
 
     url_params = ['adom', 'wanprof']
-    module_primary_key = None
+    module_primary_key = 'seq-num'
     module_arg_spec = {
         'adom': {'required': True, 'type': 'str'},
         'wanprof': {'required': True, 'type': 'str'},
@@ -261,7 +270,7 @@ def main():
             'type': 'dict',
             'v_range': [['6.4.1', '']],
             'options': {
-                '_dynamic-member': {'v_range': [['6.4.1', '6.4.13']], 'type': 'str'},
+                '_dynamic-member': {'v_range': [['6.4.1', '6.4.14']], 'type': 'str'},
                 'comment': {'v_range': [['6.4.1', '']], 'type': 'str'},
                 'cost': {'v_range': [['6.4.1', '']], 'type': 'int'},
                 'gateway': {'v_range': [['6.4.1', '']], 'type': 'str'},
@@ -269,7 +278,7 @@ def main():
                 'ingress-spillover-threshold': {'v_range': [['6.4.1', '']], 'type': 'int'},
                 'interface': {'v_range': [['6.4.1', '']], 'type': 'str'},
                 'priority': {'v_range': [['6.4.1', '']], 'type': 'int'},
-                'seq-num': {'v_range': [['6.4.1', '']], 'type': 'int'},
+                'seq-num': {'v_range': [['6.4.1', '']], 'required': True, 'type': 'int'},
                 'source': {'v_range': [['6.4.1', '']], 'type': 'str'},
                 'source6': {'v_range': [['6.4.1', '']], 'type': 'str'},
                 'spillover-threshold': {'v_range': [['6.4.1', '']], 'type': 'int'},
@@ -279,7 +288,9 @@ def main():
                 'zone': {'v_range': [['6.4.1', '']], 'type': 'str'},
                 'priority6': {'v_range': [['7.0.0', '']], 'type': 'int'},
                 'preferred-source': {'v_range': [['7.4.0', '']], 'type': 'str'},
-                'transport-group': {'v_range': [['7.4.2', '']], 'type': 'int'}
+                'transport-group': {'v_range': [['7.4.2', '']], 'type': 'int'},
+                'priority-in-sla': {'v_range': [['7.6.0', '']], 'type': 'int'},
+                'priority-out-sla': {'v_range': [['7.6.0', '']], 'type': 'int'}
             }
 
         }
@@ -290,14 +301,11 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'wanprof_system_sdwan_members'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
     fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
     fmgr.process_curd(argument_specs=module_arg_spec)
