@@ -105,13 +105,13 @@ def __convert_version_to_number(version):
     version = version[1:] if version.startswith('v') else version
     seg = version.split('.')
     if len(seg) != 3:
-        raise "Invalid fortios system version number: " + version + ". Should be of format [major].[minor].[patch]"
+        raise Exception("Invalid fortios system version number: " + version + ". Should be of format [major].[minor].[patch]")
     return int(seg[0]) * 10000 + int(seg[1]) * 100 + int(seg[2])
 
 
 def __format_single_range_desc(one_range):
     if len(one_range) != 2:
-        raise BaseException("Incorrect version range, expecting [start, end]: " + str(one_range))
+        raise Exception("Incorrect version range, expecting [start, end]: " + str(one_range))
 
     if one_range[0] == one_range[1]:
         return one_range[0]
@@ -185,7 +185,7 @@ def __check_version(revisions, version):
 
 def __concat_attribute_sequence(trace_path):
     rdata = ''
-    if type(trace_path) is not list:
+    if not isinstance(trace_path, list):
         raise AssertionError()
     if len(trace_path) >= 1:
         rdata += str(trace_path[0])
@@ -205,13 +205,13 @@ def check_schema_versioning_internal(results, trace, schema, params, version):
         return
 
     if schema['type'] == 'list':
-        if type(params) is not list:
+        if not isinstance(params, list):
             raise AssertionError()
         if 'children' in schema:
             if 'options' in schema:
                 raise AssertionError()
             for list_item in params:
-                if type(list_item) is not dict:
+                if not isinstance(list_item, dict):
                     # Parameter inconsistency here is not covered by Ansible, we gracefully throw a warning
                     results['mismatches'].append('option [%s]\' playload is inconsistent with schema.' % (__concat_attribute_sequence(trace)))
                     continue
@@ -236,7 +236,7 @@ def check_schema_versioning_internal(results, trace, schema, params, version):
                 check_schema_versioning_internal(results, trace, target_option, param, version)
                 del trace[-1]
     elif schema['type'] == 'dict':
-        if type(params) is not dict:
+        if not isinstance(params, dict):
             raise AssertionError()
         if 'children' in schema:
             for dict_item_key in params:
@@ -312,7 +312,7 @@ class FortiOSHandler(object):
 
         if type(attr_params) not in [list, dict]:
             raise AssertionError('Invalid attribute type')
-        if type(attr_params) is dict:
+        if isinstance(attr_params, dict):
             trace_param_item = dict()
             trace_param_item[current_attr_name] = (None, attr_params)
             trace_param.append(trace_param_item)
@@ -438,9 +438,8 @@ class FortiOSHandler(object):
                         changed = True
         self._module.exit_json(meta=meta, changed=changed, failed=failed)
 
-    def do_member_operation(self, path, name):
+    def do_member_operation(self, path, name, data):
         toplevel_name = (path + '_' + name).replace('-', '_').replace('.', '_').replace('+', 'plus')
-        data = self._module.params
         if not data['member_state']:
             return
         if not data['member_path']:
@@ -459,7 +458,7 @@ class FortiOSHandler(object):
             raise AssertionError('parameter %s or %s.%s empty!' % (toplevel_name, toplevel_name, self._mkeyname))
         toplevel_url_token = ''
         if state_present:
-            toplevel_url_token = '/%s' % (data[toplevel_name][self._mkeyname])
+            toplevel_url_token = '/%s' % urlencoding.quote(data[toplevel_name][self._mkeyname])
 
         # here we get both module arg spec and provided params
         arg_spec = self._module.argument_spec[toplevel_name]['options']
@@ -609,14 +608,11 @@ class FortiOSHandler(object):
             mkey = self.get_mkey(path, name, data, vdom=vdom)
         url = self.cmdb_url(path, name, vdom, mkey)
 
-        http_status, result_data = self._conn.send_request(url=url, params=parameters, data=json.dumps(data), method='PUT')
-
-        if parameters and 'action' in parameters and parameters['action'] == 'move':
-            return self.formatresponse(result_data, http_status, vdom=vdom)
-
-        if http_status == 404 or http_status == 405 or http_status == 500:
+        http_get_status, unused_response_data = self._conn.send_request(url=url, params=parameters, method='GET')
+        if http_get_status != 200:
             return self.post(path, name, data, vdom, mkey)
         else:
+            http_status, result_data = self._conn.send_request(url=url, params=parameters, data=json.dumps(data), method='PUT')
             return self.formatresponse(result_data, http_status, vdom=vdom)
 
     def post(self, path, name, data, vdom=None,
@@ -652,7 +648,7 @@ class FortiOSHandler(object):
             resp = json.loads(data)
         except Exception:
             resp = {'raw': data}
-        if is_array and type(resp) is not list:
+        if is_array and not isinstance(resp, list):
             resp = [resp]
         if is_array and 'http_status' not in resp[0]:
             resp[0]['http_status'] = http_status
@@ -669,7 +665,7 @@ class FortiOSHandler(object):
         return resp
 
     def jsonraw(self, method, path, data, specific_params, vdom=None, parameters=None):
-        url = path
+        url = urlencoding.quote(path)
         bvdom = False
         if vdom:
             if vdom == "global":
