@@ -102,7 +102,8 @@ options:
     - A valid signed certicate in PEM format (Base64 encoded)
     - Includes the "-----BEGIN CERTIFICATE-----" and "-----END CERTIFICATE-----" lines
     - Does not exceed 3000 characters in length
-  intermeadiate_cert:
+  intermediate_cert:
+    aliases: [ intermeadiate_cert ]
     type: str
     description:
     - Intermeadiate certificate provided by the CA
@@ -201,6 +202,9 @@ from ansible_collections.purestorage.flashblade.plugins.module_utils.purefb impo
 )
 
 
+CERT_TYPE_VERSION = "2.15"
+
+
 def update_cert(module, blade):
     """Update existing SSL Certificate"""
     changed = False
@@ -286,18 +290,33 @@ def update_cert(module, blade):
 
 def create_cert(module, blade):
     changed = True
-    certificate = flashblade.CertificatePost(
-        common_name=module.params["common_name"],
-        country=module.params["country"],
-        email=module.params["email"],
-        key_size=module.params["key_size"],
-        locality=module.params["locality"],
-        organization=module.params["organization"],
-        organizational_unit=module.params["org_unit"],
-        state=module.params["province"],
-        status="self-signed",
-        days=module.params["days"],
-    )
+    if CERT_TYPE_VERSION in list(blade.get_versions().items):
+        certificate = flashblade.CertificatePost(
+            certificate_type="array",
+            common_name=module.params["common_name"],
+            country=module.params["country"],
+            email=module.params["email"],
+            key_size=module.params["key_size"],
+            locality=module.params["locality"],
+            organization=module.params["organization"],
+            organizational_unit=module.params["org_unit"],
+            state=module.params["province"],
+            status="self-signed",
+            days=module.params["days"],
+        )
+    else:
+        certificate = flashblade.CertificatePost(
+            common_name=module.params["common_name"],
+            country=module.params["country"],
+            email=module.params["email"],
+            key_size=module.params["key_size"],
+            locality=module.params["locality"],
+            organization=module.params["organization"],
+            organizational_unit=module.params["org_unit"],
+            state=module.params["province"],
+            status="self-signed",
+            days=module.params["days"],
+        )
     if not module.check_mode:
         res = blade.post_certificates(
             names=[module.params["name"]], certificate=certificate
@@ -330,22 +349,48 @@ def delete_cert(module, blade):
 def import_cert(module, blade, reimport=False):
     """Import a CA provided SSL certificate"""
     changed = True
-    certificate = flashblade.CertificatePost(
-        certificate=module.params["certificate"],
-        intermediate_certificate=module.params["intermeadiate_cert"],
-        key_size=module.params["key_size"],
-        passphrase=module.params["passphrase"],
-        status="imported",
-    )
     if not module.check_mode:
         if reimport:
+            certificate = flashblade.CertificatePatch(
+                certificate=module.params["certificate"],
+                intermediate_certificate=module.params["intermediate_cert"],
+                passphrase=module.params["passphrase"],
+                private_key=module.params["key"],
+            )
             res = blade.patch_certificates(
                 names=[module.params["name"]], certificate=certificate
             )
         else:
+            if CERT_TYPE_VERSION in list(blade.get_versions().items):
+                certificate = flashblade.CertificatePost(
+                    certificate_type="external",
+                    certificate=module.params["certificate"],
+                    intermediate_certificate=module.params["intermediate_cert"],
+                    key_size=module.params["key_size"],
+                    passphrase=module.params["passphrase"],
+                    status="imported",
+                )
+            else:
+                certificate = flashblade.CertificatePost(
+                    certificate=module.params["certificate"],
+                    intermediate_certificate=module.params["intermediate_cert"],
+                    key_size=module.params["key_size"],
+                    passphrase=module.params["passphrase"],
+                    status="imported",
+                )
             res = blade.post_certificates(
                 names=[module.params["name"]], certificate=certificate
             )
+            certificate = flashblade.CertificatePatch(
+                certificate=module.params["certificate"],
+                intermediate_certificate=module.params["intermediate_cert"],
+                passphrase=module.params["passphrase"],
+                private_key=module.params["key"],
+            )
+            if res.status_code == 200:
+                res = blade.patch_certificates(
+                    names=[module.params["name"]], certificate=certificate
+                )
         if res.status_code != 200:
             module.fail_json(
                 msg="Importing Certificate failed. Error: {0}".format(
@@ -470,7 +515,9 @@ def main():
             email=dict(type="str"),
             key_size=dict(type="int", default=2048, choices=[1024, 2048, 4096]),
             certificate=dict(type="str", no_log=True, aliases=["contents"]),
-            intermeadiate_cert=dict(type="str", no_log=True),
+            intermediate_cert=dict(
+                type="str", no_log=True, aliases=["intermeadiate_cert"]
+            ),
             key=dict(type="str", no_log=True, aliases=["private_key"]),
             export_file=dict(type="str"),
             passphrase=dict(type="str", no_log=True),
